@@ -15,6 +15,14 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+import contextlib
+import os
+import random
+import shutil
+import string
+import subprocess
+import tempfile
+import urllib
 from time import sleep
 
 import requests
@@ -49,15 +57,19 @@ def get_app_module(app_name):
 
 
 def get_app_checkbox_id(app_name):
-    checkbox_id = 'id_is_enabled'
+    checkbox_id = 'app-toggle-input'
     if app_name in app_checkbox_id:
         checkbox_id = app_checkbox_id[app_name]
     return checkbox_id
 
 
-def install(browser, app_name):
+def _find_install_button(browser, app_name):
     interface.nav_to_module(browser, get_app_module(app_name))
-    install = browser.find_by_css('.form-install input[type=submit]')
+    return browser.find_by_css('.form-install input[type=submit]')
+
+
+def install(browser, app_name):
+    install_button = _find_install_button(browser, app_name)
 
     def install_in_progress():
         selectors = [
@@ -81,35 +93,51 @@ def install(browser, app_name):
             return
         wait_for_install()
 
-    if install:
-        install.click()
+    if install_button:
+        install_button.click()
         wait_for_install()
-        sleep(2)  # XXX This shouldn't be required.
+        # sleep(2)  # XXX This shouldn't be required.
 
 
 def is_installed(browser, app_name):
-    interface.nav_to_module(browser, get_app_module(app_name))
-    install_button = browser.find_by_css('.form-install input[type=submit]')
+    install_button = _find_install_button(browser, app_name)
     return not bool(install_button)
 
 
-def _change_status(browser, app_name, change_status_to='enabled',
-                   checkbox_id=None):
-    interface.nav_to_module(browser, get_app_module(app_name))
-    checkbox_id = checkbox_id or get_app_checkbox_id(app_name)
+def _change_app_status(browser, app_name, change_status_to='enabled'):
+    """Enable or disable application."""
+    button = browser.find_by_id('app-toggle-button')
+    checkbox_id = get_app_checkbox_id(app_name)
+    checkbox = browser.find_by_id(checkbox_id)
+    if button:
+        if checkbox.checked and change_status_to == 'disabled' or (
+                not checkbox.checked and change_status_to == 'enabled'):
+            interface.submit(browser, element=button)
+    else:
+        _change_status(browser, app_name, checkbox_id, change_status_to)
+
+    if app_name in apps_with_loaders:
+        wait_for_config_update(browser, app_name)
+
+
+def _change_status(browser, app_name, checkbox_id, change_status_to='enabled'):
+    """Change checkbox status."""
     checkbox = browser.find_by_id(checkbox_id)
     checkbox.check() if change_status_to == 'enabled' else checkbox.uncheck()
     interface.submit(browser, form_class='form-configuration')
+
     if app_name in apps_with_loaders:
         wait_for_config_update(browser, app_name)
 
 
 def enable(browser, app_name):
-    _change_status(browser, app_name, 'enabled')
+    interface.nav_to_module(browser, get_app_module(app_name))
+    _change_app_status(browser, app_name, 'enabled')
 
 
 def disable(browser, app_name):
-    _change_status(browser, app_name, 'disabled')
+    interface.nav_to_module(browser, get_app_module(app_name))
+    _change_app_status(browser, app_name, 'disabled')
 
 
 def wait_for_config_update(browser, app_name):
@@ -258,29 +286,27 @@ def verify_inaccessible_share(browser, name):
 def enable_mediawiki_public_registrations(browser):
     """Enable public registrations in MediaWiki."""
     interface.nav_to_module(browser, 'mediawiki')
-    _change_status(browser, 'mediawiki', 'enabled',
-                   checkbox_id='id_enable_public_registrations')
+    _change_status(browser, 'mediawiki', 'id_enable_public_registrations',
+                   'enabled')
 
 
 def disable_mediawiki_public_registrations(browser):
     """Enable public registrations in MediaWiki."""
     interface.nav_to_module(browser, 'mediawiki')
-    _change_status(browser, 'mediawiki', 'disabled',
-                   checkbox_id='id_enable_public_registrations')
+    _change_status(browser, 'mediawiki', 'id_enable_public_registrations',
+                   'disabled')
 
 
 def enable_mediawiki_private_mode(browser):
     """Enable public registrations in MediaWiki."""
     interface.nav_to_module(browser, 'mediawiki')
-    _change_status(browser, 'mediawiki', 'enabled',
-                   checkbox_id='id_enable_private_mode')
+    _change_status(browser, 'mediawiki', 'id_enable_private_mode', 'enabled')
 
 
 def disable_mediawiki_private_mode(browser):
     """Enable public registrations in MediaWiki."""
     interface.nav_to_module(browser, 'mediawiki')
-    _change_status(browser, 'mediawiki', 'disabled',
-                   checkbox_id='id_enable_private_mode')
+    _change_status(browser, 'mediawiki', 'id_enable_private_mode', 'disabled')
 
 
 def set_mediawiki_admin_password(browser, password):
@@ -293,15 +319,13 @@ def set_mediawiki_admin_password(browser, password):
 def enable_ejabberd_message_archive_management(browser):
     """Enable Message Archive Management in Ejabberd."""
     interface.nav_to_module(browser, 'ejabberd')
-    _change_status(browser, 'ejabberd', 'enabled',
-                   checkbox_id='id_MAM_enabled')
+    _change_status(browser, 'ejabberd', 'id_MAM_enabled', 'enabled')
 
 
 def disable_ejabberd_message_archive_management(browser):
     """Enable Message Archive Management in Ejabberd."""
     interface.nav_to_module(browser, 'ejabberd')
-    _change_status(browser, 'ejabberd', 'disabled',
-                   checkbox_id='id_MAM_enabled')
+    _change_status(browser, 'ejabberd', 'id_MAM_enabled', 'disabled')
 
 
 def ejabberd_add_contact(browser):
@@ -319,10 +343,180 @@ def ejabberd_has_contact(browser):
     return eventually(site.jsxc_has_contact, [browser])
 
 
+def gitweb_create_repo(browser, repo, access=None, ok_if_exists=False):
+    """Create repository."""
+    if not gitweb_repo_exists(browser, repo, access):
+        gitweb_delete_repo(browser, repo, ignore_missing=True)
+        browser.find_link_by_href('/plinth/apps/gitweb/create/').first.click()
+        browser.find_by_id('id_gitweb-name').fill(repo)
+        if access == 'private':
+            browser.find_by_id('id_gitweb-is_private').check()
+        elif access == 'public':
+            browser.find_by_id('id_gitweb-is_private').uncheck()
+        submit(browser)
+    elif not ok_if_exists:
+        assert False, 'Repo already exists.'
+
+
+def gitweb_delete_repo(browser, repo, ignore_missing=False):
+    """Delete repository."""
+    interface.nav_to_module(browser, 'gitweb')
+    delete_link = browser.find_link_by_href(
+        '/plinth/apps/gitweb/{}/delete/'.format(repo))
+    if delete_link or not ignore_missing:
+        delete_link.first.click()
+        submit(browser)
+
+
+def gitweb_edit_repo_metadata(browser, repo, metadata):
+    """Set repository metadata."""
+    interface.nav_to_module(browser, 'gitweb')
+    browser.find_link_by_href(
+        '/plinth/apps/gitweb/{}/edit/'.format(repo)).first.click()
+    if 'name' in metadata:
+        browser.find_by_id('id_gitweb-name').fill(metadata['name'])
+    if 'description' in metadata:
+        browser.find_by_id('id_gitweb-description').fill(
+            metadata['description'])
+    if 'owner' in metadata:
+        browser.find_by_id('id_gitweb-owner').fill(metadata['owner'])
+    if 'access' in metadata:
+        if metadata['access'] == 'private':
+            browser.find_by_id('id_gitweb-is_private').check()
+        else:
+            browser.find_by_id('id_gitweb-is_private').uncheck()
+    submit(browser)
+
+
+def gitweb_get_repo_metadata(browser, repo):
+    """Get repository metadata."""
+    interface.nav_to_module(browser, 'gitweb')
+    browser.find_link_by_href(
+        '/plinth/apps/gitweb/{}/edit/'.format(repo)).first.click()
+    metadata = {}
+    for item in ['name', 'description', 'owner']:
+        metadata[item] = browser.find_by_id('id_gitweb-' + item).value
+    if browser.find_by_id('id_gitweb-is_private').value:
+        metadata['access'] = 'private'
+    else:
+        metadata['access'] = 'public'
+    return metadata
+
+
+def _gitweb_get_repo_url(repo, with_auth):
+    """"Get repository URL"""
+    scheme = 'http'
+    if default_url.startswith('https://'):
+        scheme = 'https'
+    url = default_url.split('://')[1] if '://' in default_url else default_url
+    password = 'gitweb_wrong_password'
+    if with_auth:
+        password = config['DEFAULT']['password']
+
+    return '{0}://{1}:{2}@{3}/gitweb/{4}'.format(scheme,
+                                                 config['DEFAULT']['username'],
+                                                 password, url, repo)
+
+
+@contextlib.contextmanager
+def _gitweb_temp_directory():
+    """Create temporary directory"""
+    name = tempfile.mkdtemp(prefix='plinth_test_gitweb_')
+    yield name
+    shutil.rmtree(name)
+
+
+def _gitweb_git_command_is_successful(command, cwd):
+    """Check if a command runs successfully or gives authentication error"""
+    process = subprocess.run(command, capture_output=True, cwd=cwd)
+    if process.returncode != 0:
+        if 'Authentication failed' in process.stderr.decode():
+            return False
+        print(process.stdout.decode())
+        # raise exception
+        process.check_returncode()
+    return True
+
+
+def gitweb_repo_exists(browser, repo, access=None):
+    """Check whether the repository exists."""
+    interface.nav_to_module(browser, 'gitweb')
+    links_found = browser.find_link_by_href('/gitweb/{}.git'.format(repo))
+    access_matches = True
+    if links_found and access:
+        parent = links_found.first.find_by_xpath('..').first
+        private_icon = parent.find_by_css('.repo-private-icon')
+        if access == 'private':
+            access_matches = True if private_icon else False
+        if access == 'public':
+            access_matches = True if not private_icon else False
+    return bool(links_found) and access_matches
+
+
+def gitweb_repo_is_readable(repo, with_auth=False, url_git_extension=False):
+    """Check if a git repo is readable with git client."""
+    url = _gitweb_get_repo_url(repo, with_auth)
+    if url_git_extension:
+        url = url + '.git'
+    git_command = ['git', 'clone', '-c', 'http.sslverify=false', url]
+    with _gitweb_temp_directory() as cwd:
+        return _gitweb_git_command_is_successful(git_command, cwd)
+
+
+def gitweb_repo_is_writable(repo, with_auth=False, url_git_extension=False):
+    """Check if a git repo is writable with git client."""
+    url = _gitweb_get_repo_url(repo, with_auth)
+    if url_git_extension:
+        url = url + '.git'
+
+    with _gitweb_temp_directory() as cwd:
+        subprocess.run(['mkdir', 'test-project'], check=True, cwd=cwd)
+        cwd = os.path.join(cwd, 'test-project')
+        prepare_git_repo_commands = [
+            'git init -q', 'git config http.sslVerify false',
+            'git -c "user.name=Tester" -c "user.email=tester" '
+            'commit -q --allow-empty -m "test"'
+        ]
+        for command in prepare_git_repo_commands:
+            subprocess.run(command, shell=True, check=True, cwd=cwd)
+        git_push_command = ['git', 'push', '-qf', url, 'master']
+
+        return _gitweb_git_command_is_successful(git_push_command, cwd)
+
+
+def gitweb_set_repo_access(browser, repo, access):
+    """Set repository as public or private."""
+    interface.nav_to_module(browser, 'gitweb')
+    browser.find_link_by_href(
+        '/plinth/apps/gitweb/{}/edit/'.format(repo)).first.click()
+    if access == 'private':
+        browser.find_by_id('id_gitweb-is_private').check()
+    else:
+        browser.find_by_id('id_gitweb-is_private').uncheck()
+    submit(browser)
+
+
+def gitweb_set_all_repos_private(browser):
+    """Set all repositories private"""
+    interface.nav_to_module(browser, 'gitweb')
+    public_repos = []
+    for element in browser.find_by_css('#gitweb-repo-list .list-group-item'):
+        if not element.find_by_css('.repo-private-icon'):
+            repo = element.find_by_css('.repo-label').first.text
+            public_repos.append(repo)
+    for repo in public_repos:
+        gitweb_set_repo_access(browser, repo, 'private')
+
+
+def gitweb_site_repo_exists(browser, repo):
+    """Check whether the repository exists on Gitweb site."""
+    browser.visit('{}/gitweb'.format(default_url))
+    return browser.find_by_css('a[href="/gitweb/{0}.git"]'.format(repo))
+
+
 def ikiwiki_create_wiki_if_needed(browser):
     """Create wiki if it does not exist."""
     interface.nav_to_module(browser, 'ikiwiki')
-    browser.find_link_by_href('/plinth/apps/ikiwiki/manage/').first.click()
     wiki = browser.find_link_by_href('/ikiwiki/wiki')
     if not wiki:
         browser.find_link_by_href('/plinth/apps/ikiwiki/create/').first.click()
@@ -337,7 +531,6 @@ def ikiwiki_create_wiki_if_needed(browser):
 def ikiwiki_delete_wiki(browser):
     """Delete wiki."""
     interface.nav_to_module(browser, 'ikiwiki')
-    browser.find_link_by_href('/plinth/apps/ikiwiki/manage/').first.click()
     browser.find_link_by_href(
         '/plinth/apps/ikiwiki/wiki/delete/').first.click()
     submit(browser)
@@ -346,7 +539,6 @@ def ikiwiki_delete_wiki(browser):
 def ikiwiki_wiki_exists(browser):
     """Check whether the wiki exists."""
     interface.nav_to_module(browser, 'ikiwiki')
-    browser.find_link_by_href('/plinth/apps/ikiwiki/manage/').first.click()
     wiki = browser.find_link_by_href('/ikiwiki/wiki')
     return bool(wiki)
 
@@ -480,6 +672,79 @@ def openvpn_download_profile(browser):
     return _download_file(browser, url)
 
 
+def samba_set_share(browser, share_type, status='enabled'):
+    """Enable or disable samba share."""
+    disk_name = 'disk'
+    share_type_name = '{0}_share'.format(share_type)
+    interface.nav_to_module(browser, 'samba')
+    for elem in browser.find_by_tag('td'):
+        if elem.text == disk_name:
+            share_form = elem.find_by_xpath('(..//*)[2]/form').first
+            share_btn = share_form.find_by_name(share_type_name).first
+            if status == 'enabled' and share_btn['value'] == 'enable':
+                share_btn.click()
+            elif status == 'disabled' and share_btn['value'] == 'disable':
+                share_btn.click()
+            break
+
+
+def _samba_write_to_share(share_type, as_guest=False):
+    """Write to the samba share, return output messages as string."""
+    disk_name = 'disk'
+    if share_type == 'open':
+        share_name = disk_name
+    else:
+        share_name = '{0}_{1}'.format(disk_name, share_type)
+    hostname = urllib.parse.urlparse(default_url).hostname
+    servicename = '\\\\{0}\\{1}'.format(hostname, share_name)
+    directory = '_plinth-test_{0}'.format(''.join(
+        random.SystemRandom().choices(string.ascii_letters, k=8)))
+    port = config['DEFAULT']['samba_port']
+
+    smb_command = ['smbclient', '-W', 'WORKGROUP', '-p', port]
+    if as_guest:
+        smb_command += ['-N']
+    else:
+        smb_command += [
+            '-U', '{0}%{1}'.format(config['DEFAULT']['username'],
+                                   config['DEFAULT']['password'])
+        ]
+    smb_command += [
+        servicename, '-c', 'mkdir {0}; rmdir {0}'.format(directory)
+    ]
+
+    return subprocess.check_output(smb_command).decode()
+
+
+def samba_assert_share_is_writable(share_type, as_guest=False):
+    """Assert that samba share is writable."""
+    output = _samba_write_to_share(share_type, as_guest=False)
+
+    assert not output, output
+
+
+def samba_assert_share_is_not_accessible(share_type, as_guest=False):
+    """Assert that samba share is not accessible."""
+    try:
+        _samba_write_to_share(share_type, as_guest)
+    except subprocess.CalledProcessError as err:
+        err_output = err.output.decode()
+        assert 'NT_STATUS_ACCESS_DENIED' in err_output, err_output
+    else:
+        assert False, 'Can access the share.'
+
+
+def samba_assert_share_is_not_available(share_type):
+    """Assert that samba share is not accessible."""
+    try:
+        _samba_write_to_share(share_type)
+    except subprocess.CalledProcessError as err:
+        err_output = err.output.decode()
+        assert 'NT_STATUS_BAD_NETWORK_NAME' in err_output, err_output
+    else:
+        assert False, 'Can access the share.'
+
+
 def searx_enable_public_access(browser):
     """Enable Public Access in SearX"""
     interface.nav_to_module(browser, 'searx')
