@@ -15,24 +15,34 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
+import logging
+import random
+import tempfile
+
+import requests
+
 from support import config
 
 from .service import wait_for_page_update
 
 sys_modules = [
-    'avahi', 'cockpit', 'config', 'datetime', 'diagnostics', 'firewall',
-    'letsencrypt', 'monkeysphere', 'names', 'networks', 'power', 'snapshot',
-    'upgrades', 'users'
+    'avahi', 'backups', 'bind', 'cockpit', 'config', 'datetime', 'diagnostics',
+    'dynamicdns', 'firewall', 'letsencrypt', 'monkeysphere', 'names',
+    'networks', 'pagekite', 'power', 'security', 'snapshot', 'ssh', 'storage',
+    'upgrades','users'
 ]
 
 default_url = config['DEFAULT']['url']
 
 
 def login(browser, url, username, password):
-    browser.visit(url)
 
-    # XXX browser.visit goes to the web page with no cookies,
-    # hence there should be some kind of session storage for this to work
+    if '/plinth/' not in browser.url:
+        browser.visit(url)
+
+    apps_link = browser.find_link_by_href('/plinth/apps/')
+    if len(apps_link):
+        return
 
     login_button = browser.find_link_by_href('/plinth/accounts/login/')
     if login_button:
@@ -54,15 +64,10 @@ def is_login_prompt(browser):
 
 
 def nav_to_module(browser, module):
-    with wait_for_page_update(browser):
-        browser.find_link_by_href('/plinth/').first.click()
     sys_or_apps = 'sys' if module in sys_modules else 'apps'
-    with wait_for_page_update(browser):
-        browser.find_link_by_href(
-            '/plinth/{}/'.format(sys_or_apps)).first.click()
-    with wait_for_page_update(browser):
-        browser.find_link_by_href('/plinth/{0}/{1}/'.format(
-            sys_or_apps, module)).first.click()
+    required_url = default_url + f'/plinth/{sys_or_apps}/{module}/'
+    if browser.url != required_url:
+        browser.visit(required_url)
 
 
 def create_user(browser, name, password):
@@ -96,7 +101,9 @@ def delete_user(browser, name):
 
 def is_user(browser, name):
     nav_to_module(browser, 'users')
-    return browser.is_text_present(name)
+    edit_link = browser.find_link_by_href('/plinth/sys/users/' + name +
+                                          '/edit/')
+    return bool(edit_link)
 
 
 def create_admin_account(browser, username, password):
@@ -106,8 +113,8 @@ def create_admin_account(browser, username, password):
     submit(browser)
 
 
-def submit(browser, element=None, form_class=None):
-    with wait_for_page_update(browser):
+def submit(browser, element=None, form_class=None, expected_url=None):
+    with wait_for_page_update(browser, expected_url=expected_url):
         if element:
             element.click()
         elif form_class:
@@ -115,3 +122,39 @@ def submit(browser, element=None, form_class=None):
                 '.{} input[type=submit]'.format(form_class)).click()
         else:
             browser.find_by_css('input[type=submit]').click()
+
+
+def create_sample_local_file():
+    """Create a sample file for upload using browser."""
+    contents = bytearray(random.getrandbits(8) for _ in range(64))
+    with tempfile.NamedTemporaryFile(delete=False) as temp_file:
+        temp_file.write(contents)
+
+    return temp_file.name, contents
+
+
+def download_file(url):
+    """Download a file to disk given a URL."""
+    with tempfile.NamedTemporaryFile(delete=False) as temp_file:
+        logging.captureWarnings(True)
+        request = requests.get(url, verify=False)
+        logging.captureWarnings(False)
+        temp_file.write(request.content)
+
+    return temp_file.name
+
+
+def compare_files(file1, file2):
+    """Assert that the contents of two files are the same."""
+    file1_contents = open(file1, 'rb').read()
+    file2_contents = open(file2, 'rb').read()
+
+    assert file1_contents == file2_contents
+
+
+def go_to_status_logs(browser):
+    browser.visit(default_url + '/plinth/help/status-log/')
+
+
+def are_status_logs_shown(browser):
+    return browser.is_text_present('Logs begin')
