@@ -51,8 +51,9 @@ def is_available(browser, site_name):
     time.sleep(3)
     browser.reload()
     not_404 = '404' not in browser.title
-    # A trailing slash might be appended by Apache redirect rules
-    no_redirect = url_to_visit.strip('/') == browser.url.strip('/')
+    # The site might have a default path after the sitename,
+    # e.g /mediawiki/Main_Page
+    no_redirect = browser.url.startswith(url_to_visit.strip('/'))
     return not_404 and no_redirect
 
 
@@ -84,15 +85,17 @@ def upload_file_to_coquelicot(browser, file_path, password):
 
 
 def verify_mediawiki_create_account_link(browser):
-    browser.visit(config['DEFAULT']['url'] + '/mediawiki')
+    browser.visit(config['DEFAULT']['url'] +
+                  '/mediawiki/index.php/Special:CreateAccount')
     assert eventually(browser.is_element_present_by_id,
-                      args=['pt-createaccount'])
+                      args=['wpCreateaccount'])
 
 
 def verify_mediawiki_no_create_account_link(browser):
-    browser.visit(config['DEFAULT']['url'] + '/mediawiki')
+    browser.visit(config['DEFAULT']['url'] +
+                  '/mediawiki/index.php/Special:CreateAccount')
     assert eventually(browser.is_element_not_present_by_id,
-                      args=['pt-createaccount'])
+                      args=['wpCreateaccount'])
 
 
 def verify_mediawiki_anonymous_reads_edits_link(browser):
@@ -109,8 +112,8 @@ def verify_mediawiki_no_anonymous_reads_edits_link(browser):
 
 
 def _login_to_mediawiki(browser, username, password):
-    browser.visit(config['DEFAULT']['url'] + '/mediawiki')
-    browser.find_by_id('pt-login').click()
+    browser.visit(config['DEFAULT']['url'] +
+                  '/mediawiki/index.php?title=Special:Login')
     browser.find_by_id('wpName1').fill(username)
     browser.find_by_id('wpPassword1').fill(password)
     with wait_for_page_update(browser):
@@ -170,32 +173,6 @@ def _mediawiki_has_main_page(browser):
     return 'This page has been deleted.' not in content.text
 
 
-def repro_configure(browser):
-    """Configure repro."""
-    browser.visit(
-        '{}/repro/domains.html?domainUri=freedombox.local&domainTlsPort='
-        '&action=Add'.format(interface.default_url))
-
-
-def repro_delete_config(browser):
-    """Delete the repro config."""
-    browser.visit('{}/repro/domains.html?domainUri=&domainTlsPort='
-                  '&action=Remove&remove.freedombox.local=on'.format(
-                      interface.default_url))
-
-
-def repro_is_configured(browser):
-    """Check whether repro is configured."""
-    return eventually(_repro_is_configured, [browser])
-
-
-def _repro_is_configured(browser):
-    """Check whether repro is configured."""
-    browser.visit('{}/repro/domains.html'.format(interface.default_url))
-    remove = browser.find_by_name('remove.freedombox.local')
-    return bool(remove)
-
-
 def jsxc_login(browser):
     """Login to JSXC."""
     access_url(browser, 'jsxc')
@@ -293,8 +270,8 @@ def transmission_remove_all_torrents(browser):
 def transmission_upload_sample_torrent(browser):
     """Upload a sample torrent into transmission."""
     browser.visit(config['DEFAULT']['url'] + '/transmission')
-    file_path = os.path.join(
-        os.path.dirname(__file__), '..', 'data', 'sample.torrent')
+    file_path = os.path.join(os.path.dirname(__file__), '..', 'data',
+                             'sample.torrent')
     browser.click_link_by_id('toolbar-open')
     eventually(browser.is_element_not_present_by_css,
                args=['#upload-container[style="display: none;"]'])
@@ -319,8 +296,20 @@ def _deluge_get_active_window_title(browser):
 def _deluge_ensure_logged_in(browser):
     """Ensure that password dialog is answered and we can interact."""
     url = config['DEFAULT']['url'] + '/deluge'
+
+    def service_is_available():
+        if browser.is_element_present_by_xpath(
+                '//h1[text()="Service Unavailable"]'):
+            access_url(browser, 'deluge')
+            return False
+
+        return True
+
     if browser.url != url:
         browser.visit(url)
+        # After a backup restore, service may not be available immediately
+        eventually(service_is_available)
+
         time.sleep(1)  # Wait for Ext.js application in initialize
 
     if _deluge_get_active_window_title(browser) != 'Login':
@@ -345,21 +334,6 @@ def _deluge_open_connection_manager(browser):
     eventually(lambda: _deluge_get_active_window_title(browser) == title)
 
 
-def _deluge_ensure_daemon_started(browser):
-    """Start the deluge daemon if it is not started."""
-    _deluge_open_connection_manager(browser)
-
-    browser.find_by_xpath('//em[text()="127.0.0.1:58846"]').first.click()
-
-    if browser.is_element_present_by_xpath('//button[text()="Stop Daemon"]'):
-        return
-
-    browser.find_by_xpath('//button[text()="Start Daemon"]').first.click()
-
-    assert eventually(browser.is_element_present_by_xpath,
-                      args=['//button[text()="Stop Daemon"]'])
-
-
 def _deluge_ensure_connected(browser):
     """Type the connection password if required and start Deluge daemon."""
     _deluge_ensure_logged_in(browser)
@@ -368,17 +342,6 @@ def _deluge_ensure_connected(browser):
     if _deluge_get_active_window_title(browser) == 'Change Default Password':
         _deluge_click_active_window_button(browser, 'No')
 
-    # If the add button is enabled, we are already connected
-    if not browser.is_element_present_by_css('#add.x-item-disabled'):
-        return
-
-    _deluge_ensure_daemon_started(browser)
-
-    if browser.is_element_present_by_xpath('//button[text()="Disconnect"]'):
-        _deluge_click_active_window_button(browser, 'Close')
-    else:
-        _deluge_click_active_window_button(browser, 'Connect')
-
     assert eventually(browser.is_element_not_present_by_css,
                       args=['#add.x-item-disabled'])
 
@@ -394,9 +357,8 @@ def deluge_remove_all_torrents(browser):
         browser.find_by_id('remove').first.click()
 
         # Remove window shows up
-        assert eventually(
-            lambda: _deluge_get_active_window_title(browser) == 'Remove Torrent'
-        )
+        assert eventually(lambda: _deluge_get_active_window_title(browser) ==
+                          'Remove Torrent')
 
         _deluge_click_active_window_button(browser, 'Remove With Data')
 
@@ -432,22 +394,26 @@ def deluge_upload_sample_torrent(browser):
     eventually(
         lambda: _deluge_get_active_window_title(browser) == 'Add Torrents')
 
-    browser.find_by_css('button.x-deluge-add-file').first.click()
+    file_path = os.path.join(os.path.dirname(__file__), '..', 'data',
+                             'sample.torrent')
 
-    # Add from file window appears
-    eventually(
-        lambda: _deluge_get_active_window_title(browser) == 'Add from File')
+    if browser.find_by_id('fileUploadForm'):  # deluge-web 2.x
+        browser.attach_file('file', file_path)
+    else:  # deluge-web 1.x
+        browser.find_by_css('button.x-deluge-add-file').first.click()
 
-    # Attach file
-    file_path = os.path.join(
-        os.path.dirname(__file__), '..', 'data', 'sample.torrent')
-    browser.attach_file('file', file_path)
+        # Add from file window appears
+        eventually(lambda: _deluge_get_active_window_title(browser) ==
+                   'Add from File')
 
-    # Click Add
-    _deluge_click_active_window_button(browser, 'Add')
+        # Attach file
+        browser.attach_file('file', file_path)
 
-    eventually(
-        lambda: _deluge_get_active_window_title(browser) == 'Add Torrents')
+        # Click Add
+        _deluge_click_active_window_button(browser, 'Add')
+
+        eventually(
+            lambda: _deluge_get_active_window_title(browser) == 'Add Torrents')
 
     # Click Add
     time.sleep(1)
