@@ -26,4 +26,4 @@ class AppConfig(apps.AppConfig):
 
     def ready(self):
         # Signals must be loaded for axes to get the login_failed signals
-        from axes import signals  # isort:skip
+        from axes import signals  # noqa pylint: disable=unused-import isort:skip
