@@ -26,18 +26,17 @@ root = None
 file_root = None
 config_dir = None
 data_dir = None
+custom_static_dir = None
 store_file = None
 actions_dir = None
 doc_dir = None
-status_log_file = None
-access_log_file = None
 host = None
 port = None
+use_x_forwarded_for = False
 use_x_forwarded_host = False
 secure_proxy_ssl_header = None
 develop = False
 server_dir = '/'
-danube_edition = False
 
 config_file = None
 
@@ -81,10 +80,9 @@ def read(config_path=None, root_directory=None):
     global config_file  # pylint: disable-msg=invalid-name,global-statement
     config_file = config_path
 
-    parser = configparser.ConfigParser(
-        defaults={
-            'root': os.path.realpath(root_directory),
-        })
+    parser = configparser.ConfigParser(defaults={
+        'root': os.path.realpath(root_directory),
+    })
     parser.read(config_file)
 
     config_items = (
@@ -92,18 +90,17 @@ def read(config_path=None, root_directory=None):
         ('Path', 'file_root', 'string'),
         ('Path', 'config_dir', 'string'),
         ('Path', 'data_dir', 'string'),
+        ('Path', 'custom_static_dir', 'string'),
         ('Path', 'store_file', 'string'),
         ('Path', 'actions_dir', 'string'),
         ('Path', 'doc_dir', 'string'),
-        ('Path', 'status_log_file', 'string'),
-        ('Path', 'access_log_file', 'string'),
         ('Path', 'server_dir', 'string'),
         ('Network', 'host', 'string'),
         ('Network', 'port', 'int'),
         ('Network', 'secure_proxy_ssl_header', 'string'),
+        ('Network', 'use_x_forwarded_for', 'bool'),
         ('Network', 'use_x_forwarded_host', 'bool'),
         ('Misc', 'box_name', 'string'),
-        ('Misc', 'danube_edition', 'bool'),
     )
 
     for section, name, datatype in config_items:
