@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-
 """
 Project specific errors
 """
@@ -30,11 +29,6 @@ class ActionError(PlinthError):
     pass
 
 
-class DomainRegistrationError(PlinthError):
-    """Domain registration failed"""
-    pass
-
-
 class PackageNotInstalledError(PlinthError):
     """Could not complete module setup due to missing package."""
     pass
