@@ -22,7 +22,7 @@ import os
 import socket
 
 import augeas
-from django.utils.translation import ugettext_lazy
+from django.utils.translation import ugettext_lazy as _
 
 from plinth import actions
 from plinth import app as app_module
@@ -34,6 +34,13 @@ version = 2
 
 is_essential = True
 
+name = _('General Configuration')
+
+description = [
+    _('Here you can set some general configuration options '
+      'like hostname, domain name, webserver home page etc.')
+]
+
 depends = ['firewall', 'names']
 
 manual_page = 'Configure'
@@ -57,14 +64,12 @@ class ConfigApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
-        menu_item = menu.Menu('menu-config', ugettext_lazy('Configure'), None,
-                              'fa-cog', 'config:index',
-                              parent_url_name='system')
+        menu_item = menu.Menu('menu-config', _('Configure'), None, 'fa-cog',
+                              'config:index', parent_url_name='system')
         self.add(menu_item)
 
-        domain_type = DomainType('domain-type-static',
-                                 ugettext_lazy('Domain Name'), 'config:index',
-                                 can_have_certificate=True)
+        domain_type = DomainType('domain-type-static', _('Domain Name'),
+                                 'config:index', can_have_certificate=True)
         self.add(domain_type)
 
 
@@ -81,8 +86,8 @@ def get_hostname():
 
 def _get_home_page_url():
     """Get the default application for the domain."""
-    aug = augeas.Augeas(
-        flags=augeas.Augeas.NO_LOAD + augeas.Augeas.NO_MODL_AUTOLOAD)
+    aug = augeas.Augeas(flags=augeas.Augeas.NO_LOAD +
+                        augeas.Augeas.NO_MODL_AUTOLOAD)
     aug.set('/augeas/load/Httpd/lens', 'Httpd.lns')
     conf_file = APACHE_HOMEPAGE_CONFIG if os.path.exists(
         APACHE_HOMEPAGE_CONFIG) else FREEDOMBOX_APACHE_CONFIG
