@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-
 """
 URLs for the Configuration module
 """
@@ -24,5 +23,5 @@ from django.conf.urls import url
 from . import views
 
 urlpatterns = [
-    url(r'^sys/config/$', views.index, name='index'),
+    url(r'^sys/config/$', views.ConfigAppView.as_view(), name='index'),
 ]
