@@ -1,5 +1,5 @@
 #
-# This file is part of Plinth.
+# This file is part of FreedomBox.
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU Affero General Public License as
@@ -20,8 +20,8 @@ URLs for the coquelicot module.
 
 from django.conf.urls import url
 
-from .views import CoquelicotServiceView
+from .views import CoquelicotAppView
 
 urlpatterns = [
-    url(r'^apps/coquelicot/$', CoquelicotServiceView.as_view(), name='index'),
+    url(r'^apps/coquelicot/$', CoquelicotAppView.as_view(), name='index'),
 ]
