@@ -20,32 +20,32 @@ FreedomBox app to configure a Deluge web client.
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.apache.components import Webserver
 from plinth.modules.firewall.components import Firewall
-from plinth.modules.users import register_group
+from plinth.modules.users import register_group, add_user_to_share_group
 
-from .manifest import backup, clients # noqa, pylint: disable=unused-import
+from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
-version = 2
+version = 6
 
-managed_services = ['deluge-web']
+managed_services = ['deluged', 'deluge-web']
 
 managed_packages = ['deluged', 'deluge-web']
 
 name = _('Deluge')
 
+icon_filename = 'deluge'
+
 short_description = _('BitTorrent Web Client')
 
 description = [
     _('Deluge is a BitTorrent client that features a Web UI.'),
-    _('When enabled, the Deluge web client will be available from '
-      '<a href="/deluge">/deluge</a> path on the web server. The '
-      'default password is \'deluge\', but you should log in and change '
-      'it immediately after enabling this service.')
+    _('The default password is \'deluge\', but you should log in and '
+      'change it immediately after enabling this service.')
 ]
 
 group = ('bit-torrent', _('Download files using BitTorrent applications'))
@@ -73,20 +73,26 @@ class DelugeApp(app_module.App):
 
         shortcut = frontpage.Shortcut(
             'shortcut-deluge', name, short_description=short_description,
-            url='/deluge', icon='deluge', clients=clients, login_required=True,
-            allowed_groups=[group[0]])
+            url='/deluge', icon=icon_filename, clients=clients,
+            login_required=True, allowed_groups=[group[0]])
         self.add(shortcut)
 
         firewall = Firewall('firewall-deluge', name, ports=['http', 'https'],
                             is_external=True)
         self.add(firewall)
 
-        webserver = Webserver('webserver-deluge', 'deluge-plinth')
+        webserver = Webserver('webserver-deluge', 'deluge-plinth',
+                              urls=['https://{host}/deluge'])
         self.add(webserver)
 
-        daemon = Daemon('daemon-deluge', managed_services[0])
+        daemon = Daemon('daemon-deluged', managed_services[0],
+                        listen_ports=[(58846, 'tcp4')])
         self.add(daemon)
 
+        daemon_web = Daemon('daemon-deluge-web', managed_services[1],
+                            listen_ports=[(8112, 'tcp4')])
+        self.add(daemon_web)
+
 
 def init():
     """Initialize the Deluge module."""
@@ -103,17 +109,5 @@ def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
     helper.call('post', actions.superuser_run, 'deluge', ['setup'])
+    add_user_to_share_group(reserved_usernames[0])
     helper.call('post', app.enable)
-
-
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.append(action_utils.diagnose_port_listening(8112, 'tcp4'))
-    results.append(action_utils.diagnose_port_listening(8112, 'tcp6'))
-    results.extend(
-        action_utils.diagnose_url_on_all('https://{host}/deluge',
-                                         check_certificate=False))
-
-    return results
