@@ -18,6 +18,7 @@
 from django.utils.translation import ugettext_lazy as _
 
 from plinth.clients import validate
+from plinth.modules.backups.api import validate as validate_backup
 
 clients = validate([{
     'name': _('Deluge'),
@@ -27,3 +28,10 @@ clients = validate([{
         'url': '/deluge'
     }]
 }])
+
+backup = validate_backup({
+    'config': {
+        'directories': ['/var/lib/deluged/.config']
+    },
+    'services': ['deluged', 'deluge-web']
+})
