@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-
 """
 URLs for the Diagnostics module
 """
@@ -23,9 +22,8 @@ from django.conf.urls import url
 
 from . import diagnostics as views
 
-
 urlpatterns = [
     url(r'^sys/diagnostics/$', views.index, name='index'),
-    url(r'^sys/diagnostics/(?P<module_name>[1-9a-z\-]+)/$', views.module,
-        name='module'),
+    url(r'^sys/diagnostics/(?P<app_id>[1-9a-z\-]+)/$', views.diagnose_app,
+        name='app'),
 ]
