@@ -19,12 +19,12 @@ import os
 import augeas
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import frontpage, menu
 from plinth.daemon import Daemon
 from plinth.errors import DomainNotRegisteredError
-from plinth.modules.apache.components import Webserver
+from plinth.modules.apache.components import Webserver, diagnose_url
 from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
 
@@ -89,9 +89,10 @@ class DiasporaApp(app_module.App):
                               parent_url_name='apps')
         self.add(menu_item)
 
-        shortcut = Shortcut(
-            'shortcut-diaspora', name, short_description=short_description,
-            icon='diaspora', url=None, clients=clients, login_required=True)
+        shortcut = Shortcut('shortcut-diaspora', name,
+                            short_description=short_description,
+                            icon='diaspora', url=None, clients=clients,
+                            login_required=True)
         self.add(shortcut)
 
         firewall = Firewall('firewall-diaspora', name, ports=['http', 'https'],
@@ -104,10 +105,26 @@ class DiasporaApp(app_module.App):
         daemon = Daemon('daemon-diaspora', managed_services[0])
         self.add(daemon)
 
+    def diagnose(self):
+        """Run diagnostics and return the results."""
+        results = super().diagnose()
+
+        results.append(
+            diagnose_url('http://diaspora.localhost', kind='4',
+                         check_certificate=False))
+        results.append(
+            diagnose_url('http://diaspora.localhost', kind='6',
+                         check_certificate=False))
+        results.append(
+            diagnose_url(
+                'http://diaspora.{}'.format(get_configured_domain_name()),
+                kind='4', check_certificate=False))
+
+        return results
+
 
 class Shortcut(frontpage.Shortcut):
     """Frontpage shortcut to use configured domain name for URL."""
-
     def enable(self):
         """Set the proper shortcut URL when enabled."""
         super().enable()
@@ -155,32 +172,14 @@ def disable_user_registrations():
     actions.superuser_run('diaspora', ['disable-user-registrations'])
 
 
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.append(
-        action_utils.diagnose_url('http://diaspora.localhost', kind='4',
-                                  check_certificate=False))
-    results.append(
-        action_utils.diagnose_url('http://diaspora.localhost', kind='6',
-                                  check_certificate=False))
-    results.append(
-        action_utils.diagnose_url(
-            'http://diaspora.{}'.format(get_configured_domain_name()),
-            kind='4', check_certificate=False))
-
-    return results
-
-
 def generate_apache_configuration(conf_file, domain_name):
     """Generate Diaspora's apache configuration with the given domain name"""
     open(conf_file, 'w').close()
 
     diaspora_domain_name = ".".join(["diaspora", domain_name])
 
-    aug = augeas.Augeas(
-        flags=augeas.Augeas.NO_LOAD + augeas.Augeas.NO_MODL_AUTOLOAD)
+    aug = augeas.Augeas(flags=augeas.Augeas.NO_LOAD +
+                        augeas.Augeas.NO_MODL_AUTOLOAD)
 
     aug.set('/augeas/load/Httpd/lens', 'Httpd.lns')
     aug.set('/augeas/load/Httpd/incl[last() + 1]', conf_file)
