@@ -18,13 +18,14 @@
 FreedomBox app to configure ejabberd server.
 """
 
+import json
 import logging
 import pathlib
 
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
@@ -48,6 +49,8 @@ managed_paths = [pathlib.Path('/etc/ejabberd/')]
 
 name = _('ejabberd')
 
+icon_filename = 'ejabberd'
+
 short_description = _('Chat Server')
 
 description = [
@@ -95,7 +98,7 @@ class EjabberdApp(app_module.App):
 
         shortcut = frontpage.Shortcut(
             'shortcut-ejabberd', name, short_description=short_description,
-            icon='ejabberd', description=description,
+            icon=icon_filename, description=description,
             configure_url=reverse_lazy('ejabberd:index'), clients=clients,
             login_required=True)
         self.add(shortcut)
@@ -105,7 +108,8 @@ class EjabberdApp(app_module.App):
                                    'xmpp-bosh'], is_external=True)
         self.add(firewall)
 
-        webserver = Webserver('webserver-ejabberd', 'jwchat-plinth')
+        webserver = Webserver('webserver-ejabberd', 'jwchat-plinth',
+                              urls=['http://{host}/bosh/'])
         self.add(webserver)
 
         letsencrypt = LetsEncrypt(
@@ -117,7 +121,10 @@ class EjabberdApp(app_module.App):
             managing_app='ejabberd')
         self.add(letsencrypt)
 
-        daemon = Daemon('daemon-ejabberd', managed_services[0])
+        daemon = Daemon(
+            'daemon-ejabberd', managed_services[0],
+            listen_ports=[(5222, 'tcp4'), (5222, 'tcp6'), (5269, 'tcp4'),
+                          (5269, 'tcp6'), (5443, 'tcp4'), (5443, 'tcp6')])
         self.add(daemon)
 
 
@@ -162,7 +169,11 @@ def get_domains():
     if setup_helper.get_state() == 'needs-setup':
         return []
 
-    return [config.get_domainname()]
+    domain_name = config.get_domainname()
+    if domain_name:
+        return [domain_name]
+
+    return []
 
 
 def on_pre_hostname_change(sender, old_hostname, new_hostname, **kwargs):
@@ -171,6 +182,9 @@ def on_pre_hostname_change(sender, old_hostname, new_hostname, **kwargs):
     """
     del sender  # Unused
     del kwargs  # Unused
+    setup_helper = globals()['setup_helper']
+    if setup_helper.get_state() == 'needs-setup':
+        return
 
     actions.superuser_run('ejabberd', [
         'pre-change-hostname', '--old-hostname', old_hostname,
@@ -182,6 +196,9 @@ def on_post_hostname_change(sender, old_hostname, new_hostname, **kwargs):
     """Update ejabberd config after hostname change."""
     del sender  # Unused
     del kwargs  # Unused
+    setup_helper = globals()['setup_helper']
+    if setup_helper.get_state() == 'needs-setup':
+        return
 
     actions.superuser_run('ejabberd', [
         'change-hostname', '--old-hostname', old_hostname, '--new-hostname',
@@ -192,20 +209,12 @@ def on_post_hostname_change(sender, old_hostname, new_hostname, **kwargs):
 def on_domain_added(sender, domain_type, name, description='', services=None,
                     **kwargs):
     """Update ejabberd config after domain name change."""
-    actions.superuser_run('ejabberd', ['add-domain', '--domainname', name])
-    app.get_component('letsencrypt-ejabberd').setup_certificates()
+    setup_helper = globals()['setup_helper']
+    if setup_helper.get_state() == 'needs-setup':
+        return
 
-
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.append(action_utils.diagnose_port_listening(5222, 'tcp4'))
-    results.append(action_utils.diagnose_port_listening(5222, 'tcp6'))
-    results.append(action_utils.diagnose_port_listening(5269, 'tcp4'))
-    results.append(action_utils.diagnose_port_listening(5269, 'tcp6'))
-    results.append(action_utils.diagnose_port_listening(5443, 'tcp4'))
-    results.append(action_utils.diagnose_port_listening(5443, 'tcp6'))
-    results.extend(action_utils.diagnose_url_on_all('http://{host}/bosh/'))
-
-    return results
+    conf = actions.superuser_run('ejabberd', ['get-configuration'])
+    conf = json.loads(conf)
+    if name not in conf['domains']:
+        actions.superuser_run('ejabberd', ['add-domain', '--domainname', name])
+        app.get_component('letsencrypt-ejabberd').setup_certificates()
