@@ -17,6 +17,7 @@
 
 from django.utils.translation import ugettext_lazy as _
 
+from plinth.modules.backups.api import validate as validate_backup
 from plinth.clients import store_url, validate
 from plinth.modules.jsxc import manifest as jsxc_manifest
 
@@ -121,18 +122,16 @@ _clients.extend(jsxc_manifest.clients)
 
 clients = _clients
 
-backup = {
+backup = validate_backup({
     'config': {
-        'directories': [],
-        'files': ['/etc/ejabberd/ejabberd.yml'],
+        'files': ['/etc/ejabberd/ejabberd.yml']
     },
     'data': {
-        'directories': ['/var/lib/ejabberd/'],
-        'files': [],
+        'directories': ['/var/lib/ejabberd/']
     },
     'secrets': {
-        'directories': [],
         'files': ['/etc/ejabberd/ejabberd.pem'],
+        'directories': ['/etc/ejabberd/letsencrypt/']
     },
     'services': ['ejabberd']
-}
+})
