@@ -34,10 +34,10 @@ class EjabberdAppView(AppView):
     template_name = 'ejabberd.html'
     name = ejabberd.name
     description = ejabberd.description
-    diagnostics_module_name = 'ejabberd'
     form_class = EjabberdForm
     manual_page = ejabberd.manual_page
     port_forwarding_info = ejabberd.port_forwarding_info
+    icon_filename = ejabberd.icon_filename
 
     def get_initial(self):
         initdict = super().get_initial()
@@ -47,7 +47,8 @@ class EjabberdAppView(AppView):
     def get_context_data(self, *args, **kwargs):
         """Add service to the context data."""
         context = super().get_context_data(*args, **kwargs)
-        context['domainname'] = ejabberd.get_domains()[0]
+        domains = ejabberd.get_domains()
+        context['domainname'] = domains[0] if domains else None
         context['clients'] = ejabberd.clients
         return context
 
