@@ -23,6 +23,7 @@ from django.utils.translation import ugettext_lazy as _
 from plinth import actions
 from plinth import app as app_module
 from plinth import cfg, menu
+from plinth.daemon import Daemon
 from plinth.utils import Version, format_lazy
 
 from .manifest import backup  # noqa, pylint: disable=unused-import
@@ -33,6 +34,8 @@ is_essential = True
 
 managed_packages = ['firewalld', 'nftables']
 
+managed_services = ['firewalld']
+
 name = _('Firewall')
 
 description = [
@@ -62,6 +65,9 @@ class FirewallApp(app_module.App):
                               'firewall:index', parent_url_name='system')
         self.add(menu_item)
 
+        daemon = Daemon('daemon-firewall', managed_services[0])
+        self.add(daemon)
+
 
 def init():
     """Initailze firewall module"""
@@ -81,9 +87,9 @@ def force_upgrade(helper, packages):
     if 'firewalld' not in packages:
         return False
 
-    # firewalld 0.4.4.6-2 -> 0.6.x
+    # firewalld 0.6.x -> 0.7.x, 0.6.x -> 0.8.x, 0.7.x -> 0.8.x
     package = packages['firewalld']
-    if Version(package['current_version']) >= Version('0.7') or \
+    if Version(package['current_version']) >= Version('0.8') or \
        Version(package['new_version']) < Version('0.7'):
         return False
 
