@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-
 """
 URLs for the Firewall module
 """
@@ -23,7 +22,6 @@ from django.conf.urls import url
 
 from . import views
 
-
 urlpatterns = [
-    url(r'^sys/firewall/$', views.index, name='index'),
+    url(r'^sys/firewall/$', views.FirewallAppView.as_view(), name='index'),
 ]
