@@ -20,54 +20,18 @@ Help app for FreedomBox.
 
 import mimetypes
 import os
+import pathlib
 import subprocess
 
 from apt.cache import Cache
 from django.core.files.base import File
-from django.http import Http404, HttpResponse
+from django.http import Http404, HttpResponse, HttpResponseRedirect
 from django.template.response import TemplateResponse
+from django.urls import reverse
+from django.utils.translation import get_language_from_request
 from django.utils.translation import ugettext as _
-from django.utils.translation import ugettext_lazy
 
-from plinth import __version__, actions
-from plinth import app as app_module
-from plinth import cfg, menu
-
-app = None
-
-
-class HelpApp(app_module.App):
-    """FreedomBox app for showing help."""
-
-    app_id = 'help'
-
-    def __init__(self):
-        """Create components for the app."""
-        super().__init__()
-        menu_item = menu.Menu('menu-help', ugettext_lazy('Documentation'),
-                              None, 'fa-book', 'help:index',
-                              parent_url_name='index')
-        self.add(menu_item)
-        menu_item = menu.Menu('menu-help-manual', ugettext_lazy('Manual'),
-                              None, 'fa-info-circle', 'help:manual',
-                              parent_url_name='help:index', order=10)
-        self.add(menu_item)
-        menu_item = menu.Menu('menu-help-download-manual',
-                              ugettext_lazy('Download Manual'), None,
-                              'fa-download', 'help:download-manual',
-                              parent_url_name='help:index', order=15)
-        self.add(menu_item)
-        menu_item = menu.Menu('menu-help-about', ugettext_lazy('About'), None,
-                              'fa-star', 'help:about',
-                              parent_url_name='help:index', order=100)
-        self.add(menu_item)
-
-
-def init():
-    """Initialize the Help module"""
-    global app
-    app = HelpApp()
-    app.set_enabled(True)
+from plinth import __version__, actions, cfg
 
 
 def index(request):
@@ -76,6 +40,24 @@ def index(request):
                             {'title': _('Documentation and FAQ')})
 
 
+def contribute(request):
+    """Serve the contribute page"""
+    return TemplateResponse(request, 'help_contribute.html',
+                            {'title': _('Contribute')})
+
+
+def feedback(request):
+    """Serve the feedback page"""
+    return TemplateResponse(request, 'help_feedback.html',
+                            {'title': _('Submit Feedback')})
+
+
+def support(request):
+    """Serve the support page"""
+    return TemplateResponse(request, 'help_support.html',
+                            {'title': _('Get Support')})
+
+
 def about(request):
     """Serve the about page"""
     cache = Cache()
@@ -90,15 +72,28 @@ def about(request):
     return TemplateResponse(request, 'help_about.html', context)
 
 
-def manual(request, page='freedombox-manual.part.html'):
+def manual(request, lang=None, page=None):
     """Serve the manual page from the 'doc' directory"""
-    try:
-        page = '{}.part.html'.format(
-            page) if not page.endswith('html') else page
-        with open(os.path.join(cfg.doc_dir, page), 'r',
-                  encoding='utf-8') as input_file:
-            content = input_file.read()
-    except IOError:
+    if not lang or lang == '-':
+        kwargs = {'lang': get_language_from_request(request)}
+        if page:
+            return HttpResponseRedirect(
+                reverse('help:manual-page', kwargs=dict(kwargs, page=page)))
+
+        return HttpResponseRedirect(reverse('help:manual', kwargs=kwargs))
+
+    def read_file(lang, file_name):
+        """Read the page from disk and return contents or None."""
+        page_file = pathlib.Path(cfg.doc_dir) / 'manual' / lang / file_name
+        return page_file.read_text() if page_file.exists() else None
+
+    page = page or 'freedombox-manual'
+    content = read_file(lang, f'{page}.part.html')
+    if not content:
+        if lang != 'en':
+            return HttpResponseRedirect(
+                reverse('help:manual-page', kwargs=dict(lang='en', page=page)))
+
         raise Http404
 
     return TemplateResponse(
@@ -110,17 +105,26 @@ def manual(request, page='freedombox-manual.part.html'):
 
 def download_manual(request):
     """Serve the PDF version of the manual from the 'doc' directory"""
-    files = [
-        os.path.join(cfg.doc_dir, file_name)
-        for file_name in ['freedombox-manual.pdf.gz', 'freedombox-manual.pdf']
-        if os.path.isfile(os.path.join(cfg.doc_dir, file_name))
-    ]
+    language_code = get_language_from_request(request)
 
-    if not files:
+    def get_manual_file_name(language_code):
+        for file_name in ['freedombox-manual.pdf.gz', 'freedombox-manual.pdf']:
+            name = os.path.join(cfg.doc_dir, 'manual', language_code,
+                                file_name)
+            if os.path.isfile(name):
+                return name
+
+        return None
+
+    manual_file_name = get_manual_file_name(
+        language_code) or get_manual_file_name('en')
+
+    if not manual_file_name:
         raise Http404
 
-    (content_type, encoding) = mimetypes.guess_type(files[0])
-    with open(files[0], 'rb') as file_handle:
+    (content_type, encoding) = mimetypes.guess_type(manual_file_name)
+
+    with open(manual_file_name, 'rb') as file_handle:
         response = HttpResponse(File(file_handle), content_type=content_type)
         if encoding:
             response['Content-Encoding'] = encoding
