@@ -17,6 +17,7 @@
 
 from django.utils.translation import ugettext_lazy as _
 
+from plinth.modules.backups.api import validate as validate_backup
 from plinth.clients import validate
 
 clients = validate([{
@@ -27,18 +28,7 @@ clients = validate([{
     }]
 }])
 
-backup = {
-    'config': {
-        'directories': [],
-        'files': [],
-    },
-    'data': {
-        'directories': ['/var/lib/ikiwiki/'],
-        'files': [],
-    },
-    'secrets': {
-        'directories': [],
-        'files': [],
-    },
-    'services': []
-}
+backup = validate_backup(
+    {'data': {
+        'directories': ['/var/lib/ikiwiki/', '/var/www/ikiwiki/']
+    }})
