@@ -24,8 +24,6 @@ from . import views
 
 urlpatterns = [
     url(r'^apps/ikiwiki/$', views.IkiwikiAppView.as_view(), name='index'),
-    url(r'^apps/ikiwiki/manage/$', views.manage, name='manage'),
-    url(r'^apps/ikiwiki/(?P<name>[\w.@+-]+)/delete/$', views.delete,
-        name='delete'),
+    url(r'^apps/ikiwiki/(?P<name>.+)/delete/$', views.delete, name='delete'),
     url(r'^apps/ikiwiki/create/$', views.create, name='create'),
 ]
