@@ -23,61 +23,34 @@ from django.shortcuts import redirect
 from django.template.response import TemplateResponse
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext as _
-from django.utils.translation import ugettext_lazy
 
 from plinth import actions, views
 from plinth.modules import ikiwiki
 
 from .forms import IkiwikiCreateForm
 
-subsubmenu = [{
-    'url': reverse_lazy('ikiwiki:index'),
-    'text': ugettext_lazy('Configure')
-}, {
-    'url': reverse_lazy('ikiwiki:manage'),
-    'text': ugettext_lazy('Manage')
-}, {
-    'url': reverse_lazy('ikiwiki:create'),
-    'text': ugettext_lazy('Create')
-}]
-
 
 class IkiwikiAppView(views.AppView):
     """Serve configuration page."""
     app_id = 'ikiwiki'
     name = ikiwiki.name
     description = ikiwiki.description
-    diagnostics_module_name = 'ikiwiki'
     show_status_block = False
     template_name = 'ikiwiki_configure.html'
+    manual_page = ikiwiki.manual_page
+    clients = ikiwiki.clients
+    icon_filename = ikiwiki.icon_filename
 
     def get_context_data(self, **kwargs):
         """Return the context data for rendering the template view."""
+        sites = ikiwiki.app.refresh_sites()
+        sites = [name for name in sites if name != '']
+
         context = super().get_context_data(**kwargs)
-        context['title'] = ikiwiki.name
-        context['subsubmenu'] = subsubmenu
-        context['clients'] = ikiwiki.clients
-        context['manual_page'] = ikiwiki.manual_page
+        context['sites'] = sites
         return context
 
 
-def manage(request):
-    """Manage existing wikis and blogs."""
-    sites = actions.run('ikiwiki', ['get-sites']).split('\n')
-    sites = [name for name in sites if name != '']
-
-    return TemplateResponse(
-        request, 'ikiwiki_manage.html', {
-            'title': ikiwiki.name,
-            'clients': ikiwiki.clients,
-            'description': ikiwiki.description,
-            'manual_page': ikiwiki.manual_page,
-            'subsubmenu': subsubmenu,
-            'sites': sites,
-            'is_enabled': ikiwiki.app.is_enabled(),
-        })
-
-
 def create(request):
     """Form to create a wiki or blog."""
     form = None
@@ -94,11 +67,11 @@ def create(request):
                              form.cleaned_data['admin_name'],
                              form.cleaned_data['admin_password'])
 
-            site = form.cleaned_data['name'].replace(' ', '')
-            shortcut = ikiwiki.app.add_shortcut(site)
-            shortcut.enable()
+            ikiwiki.app.refresh_sites()
+            if ikiwiki.app.is_enabled():
+                ikiwiki.app.set_enabled(True)
 
-            return redirect(reverse_lazy('ikiwiki:manage'))
+            return redirect(reverse_lazy('ikiwiki:index'))
     else:
         form = IkiwikiCreateForm(prefix='ikiwiki')
 
@@ -109,7 +82,6 @@ def create(request):
             'description': ikiwiki.description,
             'form': form,
             'manual_page': ikiwiki.manual_page,
-            'subsubmenu': subsubmenu,
             'is_enabled': ikiwiki.app.is_enabled(),
         })
 
@@ -146,20 +118,22 @@ def delete(request, name):
     On GET, display a confirmation page.
     On POST, delete the wiki/blog.
     """
+    title = ikiwiki.app.components['shortcut-ikiwiki-' + name].name
     if request.method == 'POST':
         try:
             actions.superuser_run('ikiwiki', ['delete', '--name', name])
             ikiwiki.app.remove_shortcut(name)
-            messages.success(request, _('{name} deleted.').format(name=name))
+            messages.success(request,
+                             _('{title} deleted.').format(title=title))
         except actions.ActionError as error:
             messages.error(
                 request,
-                _('Could not delete {name}: {error}').format(
-                    name=name, error=error))
+                _('Could not delete {title}: {error}').format(
+                    title=title, error=error))
 
-        return redirect(reverse_lazy('ikiwiki:manage'))
+        return redirect(reverse_lazy('ikiwiki:index'))
 
     return TemplateResponse(request, 'ikiwiki_delete.html', {
         'title': ikiwiki.name,
-        'name': name
+        'name': title
     })
