@@ -21,7 +21,7 @@ FreedomBox app for infinoted.
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
@@ -29,16 +29,20 @@ from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
 from plinth.views import AppView
 
-from .manifest import backup, clients # noqa, pylint: disable=unused-import
+from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
-version = 1
+version = 2
 
 managed_services = ['infinoted']
 
 managed_packages = ['infinoted']
 
+manual_page = 'Infinoted'
+
 name = _('infinoted')
 
+icon_filename = 'infinoted'
+
 short_description = _('Gobby Server')
 
 description = [
@@ -72,7 +76,7 @@ class InfinotedApp(app_module.App):
 
         shortcut = frontpage.Shortcut(
             'shortcut-infinoted', name, short_description=short_description,
-            icon='infinoted', description=description,
+            icon=icon_filename, description=description,
             configure_url=reverse_lazy('infinoted:index'), clients=clients,
             login_required=False)
         self.add(shortcut)
@@ -81,7 +85,8 @@ class InfinotedApp(app_module.App):
                             ports=['infinoted-plinth'], is_external=True)
         self.add(firewall)
 
-        daemon = Daemon('daemon-infinoted', managed_services[0])
+        daemon = Daemon('daemon-infinoted', managed_services[0],
+                        listen_ports=[(6523, 'tcp4'), (6523, 'tcp6')])
         self.add(daemon)
 
 
@@ -97,11 +102,11 @@ def init():
 
 class InfinotedAppView(AppView):
     app_id = 'infinoted'
-    diagnostics_module_name = 'infinoted'
     name = name
     description = description
     clients = clients
     port_forwarding_info = port_forwarding_info
+    icon_filename = icon_filename
 
 
 def setup(helper, old_version=None):
@@ -109,13 +114,3 @@ def setup(helper, old_version=None):
     helper.install(managed_packages)
     helper.call('post', actions.superuser_run, 'infinoted', ['setup'])
     helper.call('post', app.enable)
-
-
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.append(action_utils.diagnose_port_listening(6523, 'tcp4'))
-    results.append(action_utils.diagnose_port_listening(6523, 'tcp6'))
-
-    return results
