@@ -24,11 +24,13 @@ import pathlib
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import cfg, menu
 from plinth.errors import ActionError
 from plinth.modules import names
+from plinth.modules.apache.components import diagnose_url
+from plinth.modules.names.components import DomainType
 from plinth.signals import domain_added, domain_removed, post_module_loading
 from plinth.utils import format_lazy
 
@@ -84,6 +86,16 @@ class LetsEncryptApp(app_module.App):
                               parent_url_name='system')
         self.add(menu_item)
 
+    def diagnose(self):
+        """Run diagnostics and return the results."""
+        results = super().diagnose()
+
+        for domain in names.components.DomainName.list():
+            if domain.domain_type.can_have_certificate:
+                results.append(diagnose_url('https://' + domain.name))
+
+        return results
+
 
 def init():
     """Initialize the module."""
@@ -105,17 +117,6 @@ def setup(helper, old_version=None):
         ['setup', '--old-version', str(old_version)])
 
 
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    for domain in names.components.DomainName.list():
-        if domain.domain_type.can_have_certificate:
-            results.append(action_utils.diagnose_url('https://' + domain.name))
-
-    return results
-
-
 def certificate_obtain(domain):
     """Obtain a certificate for a domain and notify handlers."""
     actions.superuser_run('letsencrypt', ['obtain', '--domain', domain])
@@ -151,7 +152,7 @@ def certificate_delete(domain):
 def on_domain_added(sender, domain_type='', name='', description='',
                     services=None, **kwargs):
     """Obtain a certificate for the new domain"""
-    if domain_type == 'domain-type-tor':
+    if not DomainType.get(domain_type).can_have_certificate:
         return False
 
     # Check if a cert if already available
@@ -162,9 +163,8 @@ def on_domain_added(sender, domain_type='', name='', description='',
             return False
 
     try:
-        # Obtaining certs during tests or empty names isn't expected to succeed
-        if sender != 'test' and name:
-            logger.info('Obtaining a Let\'s Encrypt certificate for %s', name)
+        if name:
+            logger.info('Obtaining certificate for %s', name)
             certificate_obtain(name)
         return True
     except ActionError:
@@ -173,16 +173,17 @@ def on_domain_added(sender, domain_type='', name='', description='',
 
 def on_domain_removed(sender, domain_type, name='', **kwargs):
     """Revoke Let's Encrypt certificate for the removed domain"""
+    if not DomainType.get(domain_type).can_have_certificate:
+        return False
+
     try:
-        # Revoking certs during tests or empty names isn't expected to succeed
-        if sender != 'test' and name:
-            logger.info("Revoking the Let\'s Encrypt certificate for " + name)
+        if name:
+            logger.info('Revoking certificate for %s', name)
             certificate_revoke(name)
         return True
     except ActionError as exception:
-        logger.warning(
-            ('Failed to revoke certificate for domain {domain}: {error}'
-             ).format(domain=name, error=exception.args[2]))
+        logger.warning('Failed to revoke certificate for %s: %s', name,
+                       exception.args[2])
         return False
 
 
