@@ -26,15 +26,16 @@ from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 from ruamel.yaml.util import load_yaml_guess_indent
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.apache.components import Webserver
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.letsencrypt.components import LetsEncrypt
+from plinth.utils import Version
 
-from .manifest import backup, clients # noqa, pylint: disable=unused-import
+from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
 version = 5
 
@@ -46,6 +47,8 @@ managed_paths = [pathlib.Path('/etc/matrix-synapse/')]
 
 name = _('Matrix Synapse')
 
+icon_filename = 'matrixsynapse'
+
 short_description = _('Chat Server')
 
 description = [
@@ -91,7 +94,7 @@ class MatrixSynapseApp(app_module.App):
 
         shortcut = frontpage.Shortcut(
             'shortcut-matrixsynapse', name,
-            short_description=short_description, icon='matrixsynapse',
+            short_description=short_description, icon=icon_filename,
             description=description,
             configure_url=reverse_lazy('matrixsynapse:index'), clients=clients,
             login_required=True)
@@ -102,20 +105,21 @@ class MatrixSynapseApp(app_module.App):
         self.add(firewall)
 
         webserver = Webserver('webserver-matrixsynapse',
-                              'matrix-synapse-plinth')
+                              'matrix-synapse-plinth',
+                              urls=['https://{host}/_matrix/client/versions'])
         self.add(webserver)
 
         letsencrypt = LetsEncrypt(
-            'letsencrypt-matrixsynapse', domains=get_domains, daemons=[
-                managed_services[0]
-            ], should_copy_certificates=True,
+            'letsencrypt-matrixsynapse', domains=get_domains,
+            daemons=[managed_services[0]], should_copy_certificates=True,
             private_key_path='/etc/matrix-synapse/homeserver.tls.key',
             certificate_path='/etc/matrix-synapse/homeserver.tls.crt',
             user_owner='matrix-synapse', group_owner='nogroup',
             managing_app='matrixsynapse')
         self.add(letsencrypt)
 
-        daemon = Daemon('daemon-matrixsynapse', managed_services[0])
+        daemon = Daemon('daemon-matrixsynapse', managed_services[0],
+                        listen_ports=[(8008, 'tcp4'), (8448, 'tcp4')])
         self.add(daemon)
 
 
@@ -138,6 +142,26 @@ def setup(helper, old_version=None):
     app.get_component('letsencrypt-matrixsynapse').setup_certificates()
 
 
+def force_upgrade(helper, packages):
+    """Force upgrade matrix-synapse to resolve conffile prompt."""
+    if 'matrix-synapse' not in packages:
+        return False
+
+    # Allow any lower version to upgrade to 1.8.*
+    package = packages['matrix-synapse']
+    if Version(package['new_version']) > Version('1.9~'):
+        return False
+
+    public_registration_status = get_public_registration_status()
+    helper.install(['matrix-synapse'], force_configuration='new')
+    actions.superuser_run('matrixsynapse', ['post-install'])
+    if public_registration_status:
+        actions.superuser_run('matrixsynapse',
+                              ['public-registration', 'enable'])
+
+    return True
+
+
 def setup_domain(domain_name):
     """Configure a domain name for matrixsynapse."""
     app.get_component('letsencrypt-matrixsynapse').setup_certificates(
@@ -151,19 +175,6 @@ def is_setup():
     return os.path.exists(SERVER_NAME_PATH)
 
 
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.append(action_utils.diagnose_port_listening(8008, 'tcp4'))
-    results.append(action_utils.diagnose_port_listening(8448, 'tcp4'))
-    results.extend(
-        action_utils.diagnose_url_on_all(
-            'https://{host}/_matrix/client/versions', check_certificate=False))
-
-    return results
-
-
 def get_domains():
     """Return a list of domains this app is interested in."""
     domain = get_configured_domain_name()
