@@ -18,18 +18,20 @@
 FreedomBox app to configure MediaWiki.
 """
 
+import re
+
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.apache.components import Webserver
 from plinth.modules.firewall.components import Firewall
 
-from .manifest import backup, clients # noqa, pylint: disable=unused-import
+from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
-version = 6
+version = 7
 
 managed_packages = ['mediawiki', 'imagemagick', 'php-sqlite3']
 
@@ -37,6 +39,8 @@ managed_services = ['mediawiki-jobrunner']
 
 name = _('MediaWiki')
 
+icon_filename = 'mediawiki'
+
 short_description = _('Wiki')
 
 description = [
@@ -78,7 +82,7 @@ class MediaWikiApp(app_module.App):
 
         shortcut = Shortcut('shortcut-mediawiki', name,
                             short_description=short_description,
-                            icon='mediawiki', url='/mediawiki',
+                            icon=icon_filename, url='/mediawiki',
                             clients=clients, login_required=True)
         self.add(shortcut)
 
@@ -86,7 +90,8 @@ class MediaWikiApp(app_module.App):
                             ports=['http', 'https'], is_external=True)
         self.add(firewall)
 
-        webserver = Webserver('webserver-mediawiki', 'mediawiki')
+        webserver = Webserver('webserver-mediawiki', 'mediawiki',
+                              urls=['https://{host}/mediawiki'])
         self.add(webserver)
 
         webserver = Webserver('webserver-mediawiki-freedombox',
@@ -99,7 +104,6 @@ class MediaWikiApp(app_module.App):
 
 class Shortcut(frontpage.Shortcut):
     """Frontpage shortcut for only logged users when in private mode."""
-
     def enable(self):
         """When enabled, check if MediaWiki is in private mode."""
         super().enable()
@@ -124,16 +128,6 @@ def setup(helper, old_version=None):
     helper.call('post', app.enable)
 
 
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.extend(
-        action_utils.diagnose_url_on_all('https://{host}/mediawiki',
-                                         check_certificate=False))
-    return results
-
-
 def is_public_registration_enabled():
     """Return whether public registration is enabled."""
     output = actions.superuser_run('mediawiki',
@@ -145,3 +139,20 @@ def is_private_mode_enabled():
     """ Return whether private mode is enabled or disabled"""
     output = actions.superuser_run('mediawiki', ['private-mode', 'status'])
     return output.strip() == 'enabled'
+
+
+def get_default_skin():
+    """Return the value of the default skin"""
+    def _find_skin(config_file):
+        with open(config_file, 'r') as config:
+            for line in config:
+                if line.startswith('$wgDefaultSkin'):
+                    return re.findall(r'["\'][^"\']*["\']',
+                                      line)[0].strip('"\'')
+
+        return None
+
+    user_config = '/etc/mediawiki/FreedomBoxSettings.php'
+    static_config = '/etc/mediawiki/FreedomBoxStaticSettings.php'
+
+    return _find_skin(user_config) or _find_skin(static_config)
