@@ -22,14 +22,13 @@ import augeas
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils
 from plinth import app as app_module
 from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
 
-from .manifest import backup, clients # noqa, pylint: disable=unused-import
+from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
 version = 2
 
@@ -42,15 +41,16 @@ mods = [
     'minetest-mod-moreblocks', 'minetest-mod-moreores', 'minetest-mod-nether',
     'minetest-mod-pipeworks', 'minetest-mod-player-3d-armor',
     'minetest-mod-protector', 'minetest-mod-quartz', 'minetest-mod-skyblock',
-    'minetest-mod-throwing', 'minetest-mod-torches',
-    'minetest-mod-unified-inventory', 'minetest-mod-unifieddyes',
-    'minetest-mod-worldedit'
+    'minetest-mod-throwing', 'minetest-mod-unified-inventory',
+    'minetest-mod-unifieddyes', 'minetest-mod-worldedit'
 ]
 
 managed_packages = ['minetest-server'] + mods
 
 name = _('Minetest')
 
+icon_filename = 'minetest'
+
 short_description = _('Block Sandbox')
 
 description = [
@@ -91,7 +91,7 @@ class MinetestApp(app_module.App):
 
         shortcut = frontpage.Shortcut(
             'shortcut-minetest', name, short_description=short_description,
-            icon='minetest', description=description,
+            icon=icon_filename, description=description,
             configure_url=reverse_lazy('minetest:index'), clients=clients,
             login_required=False)
         self.add(shortcut)
@@ -100,7 +100,8 @@ class MinetestApp(app_module.App):
                             ports=['minetest-plinth'], is_external=True)
         self.add(firewall)
 
-        daemon = Daemon('daemon-minetest', managed_services[0])
+        daemon = Daemon('daemon-minetest', managed_services[0],
+                        listen_ports=[(30000, 'udp4')])
         self.add(daemon)
 
 
@@ -120,19 +121,10 @@ def setup(helper, old_version=None):
     helper.call('post', app.enable)
 
 
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.append(action_utils.diagnose_port_listening(30000, 'udp4'))
-
-    return results
-
-
 def load_augeas():
     """Initialize Augeas."""
-    aug = augeas.Augeas(
-        flags=augeas.Augeas.NO_LOAD + augeas.Augeas.NO_MODL_AUTOLOAD)
+    aug = augeas.Augeas(flags=augeas.Augeas.NO_LOAD +
+                        augeas.Augeas.NO_MODL_AUTOLOAD)
     aug.set('/augeas/load/Php/lens', 'Php.lns')
     aug.set('/augeas/load/Php/incl[last() + 1]', CONFIG_FILE)
     aug.load()
