@@ -32,7 +32,6 @@ from .forms import MinetestForm
 class MinetestAppView(AppView):  # pylint: disable=too-many-ancestors
     """A specialized view for configuring minetest."""
     app_id = 'minetest'
-    diagnostics_module_name = 'minetest'
     name = minetest.name
     description = description
     show_status_block = True
@@ -41,6 +40,7 @@ class MinetestAppView(AppView):  # pylint: disable=too-many-ancestors
     clients = minetest.clients
     manual_page = minetest.manual_page
     port_forwarding_info = minetest.port_forwarding_info
+    icon_filename = minetest.icon_filename
 
     def get_initial(self):
         """Return the values to fill in the form."""
