@@ -26,10 +26,10 @@ from plinth.views import AppView
 urlpatterns = [
     url(
         r'^apps/mldonkey/$',
-        AppView.as_view(
-            app_id='mldonkey', name=mldonkey.name,
-            diagnostics_module_name='mldonkey',
-            description=mldonkey.description, clients=mldonkey.clients,
-            manual_page=mldonkey.manual_page, show_status_block=True),
-        name='index'),
+        AppView.as_view(app_id='mldonkey', name=mldonkey.name,
+                        description=mldonkey.description,
+                        clients=mldonkey.clients,
+                        manual_page=mldonkey.manual_page,
+                        show_status_block=True,
+                        icon_filename=mldonkey.icon_filename), name='index'),
 ]
