@@ -21,19 +21,19 @@ FreedomBox app to configure Mumble server.
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils
 from plinth import app as app_module
 from plinth import frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.firewall.components import Firewall
-from plinth.views import AppView
 
-from .manifest import backup, clients # noqa, pylint: disable=unused-import
+from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
 version = 1
 
 name = _('Mumble')
 
+icon_filename = 'mumble'
+
 short_description = _('Voice Chat')
 
 managed_services = ['mumble-server']
@@ -76,7 +76,7 @@ class MumbleApp(app_module.App):
 
         shortcut = frontpage.Shortcut(
             'shortcut-mumble', name, short_description=short_description,
-            icon='mumble', description=description,
+            icon=icon_filename, description=description,
             configure_url=reverse_lazy('mumble:index'), clients=clients)
         self.add(shortcut)
 
@@ -84,7 +84,10 @@ class MumbleApp(app_module.App):
                             is_external=True)
         self.add(firewall)
 
-        daemon = Daemon('daemon-mumble', managed_services[0])
+        daemon = Daemon(
+            'daemon-mumble', managed_services[0],
+            listen_ports=[(64738, 'tcp4'), (64738, 'tcp6'), (64738, 'udp4'),
+                          (64738, 'udp6')])
         self.add(daemon)
 
 
@@ -98,29 +101,7 @@ def init():
         app.set_enabled(True)
 
 
-class MumbleAppView(AppView):
-    app_id = 'mumble'
-    diagnostics_module_name = 'mumble'
-    name = name
-    description = description
-    clients = clients
-    manual_page = manual_page
-    port_forwarding_info = port_forwarding_info
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
     helper.call('post', app.enable)
-
-
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.append(action_utils.diagnose_port_listening(64738, 'tcp4'))
-    results.append(action_utils.diagnose_port_listening(64738, 'tcp6'))
-    results.append(action_utils.diagnose_port_listening(64738, 'udp4'))
-    results.append(action_utils.diagnose_port_listening(64738, 'udp6'))
-
-    return results
