@@ -20,7 +20,7 @@ URLs for the Mumble module
 
 from django.conf.urls import url
 
-from plinth.modules.mumble import MumbleAppView
+from plinth.modules.mumble.views import MumbleAppView
 
 urlpatterns = [
     url(r'^apps/mumble/$', MumbleAppView.as_view(), name='index'),
