@@ -15,34 +15,22 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 
-from logging import Logger
+import logging
 
 from django.contrib import messages
 from django.shortcuts import redirect
 from django.template.response import TemplateResponse
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext as _
-from django.utils.translation import ugettext_lazy
 from django.views.decorators.http import require_POST
 
-from plinth import network
-from plinth.modules import networks
+from plinth import network, kvstore
+from plinth.modules import networks, first_boot
 
 from .forms import (ConnectionTypeSelectForm, EthernetForm, GenericForm,
-                    PPPoEForm, WifiForm)
+                    PPPoEForm, WifiForm, RouterConfigurationWizardForm)
 
-logger = Logger(__name__)
-
-subsubmenu = [{
-    'url': reverse_lazy('networks:index'),
-    'text': ugettext_lazy('Network Connections')
-}, {
-    'url': reverse_lazy('networks:scan'),
-    'text': ugettext_lazy('Nearby Wi-Fi Networks')
-}, {
-    'url': reverse_lazy('networks:add'),
-    'text': ugettext_lazy('Add Connection')
-}]
+logger = logging.getLogger(__name__)
 
 
 def index(request):
@@ -51,9 +39,13 @@ def index(request):
 
     return TemplateResponse(
         request, 'connections_list.html', {
+            'app_id': 'networks',
             'title': _('Network Connections'),
+            'name': networks.name,
+            'description': networks.description,
             'manual_page': networks.manual_page,
-            'subsubmenu': subsubmenu,
+            'has_diagnostics': True,
+            'is_enabled': True,
             'connections': connections
         })
 
@@ -100,7 +92,6 @@ def show(request, uuid):
     return TemplateResponse(
         request, 'connection_show.html', {
             'title': _('Connection Information'),
-            'subsubmenu': subsubmenu,
             'connection': connection_status,
             'active_connection': active_connection_status,
             'device': device_status,
@@ -141,12 +132,10 @@ def edit(request, uuid):
 
             return redirect(reverse_lazy('networks:index'))
         else:
-            return TemplateResponse(
-                request, 'connections_edit.html', {
-                    'title': _('Edit Connection'),
-                    'subsubmenu': subsubmenu,
-                    'form': form
-                })
+            return TemplateResponse(request, 'connections_edit.html', {
+                'title': _('Edit Connection'),
+                'form': form
+            })
     else:
         settings_connection = connection.get_setting_connection()
         form_data['interface'] = connection.get_interface_name()
@@ -229,7 +218,6 @@ def edit(request, uuid):
 
         return TemplateResponse(request, 'connections_edit.html', {
             'title': _('Edit Connection'),
-            'subsubmenu': subsubmenu,
             'form': form
         })
 
@@ -243,14 +231,16 @@ def activate(request, uuid):
         messages.success(request,
                          _('Activated connection {name}.').format(name=name))
     except network.ConnectionNotFound:
-        messages.error(request,
-                       _('Failed to activate connection: '
-                         'Connection not found.'))
+        messages.error(
+            request,
+            _('Failed to activate connection: '
+              'Connection not found.'))
     except network.DeviceNotFound as exception:
         name = exception.args[0].get_id()
-        messages.error(request,
-                       _('Failed to activate connection {name}: '
-                         'No suitable device is available.').format(name=name))
+        messages.error(
+            request,
+            _('Failed to activate connection {name}: '
+              'No suitable device is available.').format(name=name))
 
     return redirect(reverse_lazy('networks:index'))
 
@@ -264,9 +254,10 @@ def deactivate(request, uuid):
         messages.success(request,
                          _('Deactivated connection {name}.').format(name=name))
     except network.ConnectionNotFound:
-        messages.error(request,
-                       _('Failed to de-activate connection: '
-                         'Connection not found.'))
+        messages.error(
+            request,
+            _('Failed to de-activate connection: '
+              'Connection not found.'))
 
     return redirect(reverse_lazy('networks:index'))
 
@@ -274,12 +265,10 @@ def deactivate(request, uuid):
 def scan(request):
     """Show a list of nearby visible Wi-Fi access points."""
     access_points = network.wifi_scan()
-    return TemplateResponse(
-        request, 'wifi_scan.html', {
-            'title': _('Nearby Wi-Fi Networks'),
-            'subsubmenu': subsubmenu,
-            'access_points': access_points
-        })
+    return TemplateResponse(request, 'wifi_scan.html', {
+        'title': _('Nearby Wi-Fi Networks'),
+        'access_points': access_points
+    })
 
 
 def add(request):
@@ -302,7 +291,6 @@ def add(request):
         form = ConnectionTypeSelectForm()
         return TemplateResponse(request, 'connections_type_select.html', {
             'title': _('Add Connection'),
-            'subsubmenu': subsubmenu,
             'form': form
         })
 
@@ -319,12 +307,10 @@ def add_generic(request):
     else:
         form = GenericForm()
 
-    return TemplateResponse(
-        request, 'connections_create.html', {
-            'title': _('Adding New Generic Connection'),
-            'subsubmenu': subsubmenu,
-            'form': form
-        })
+    return TemplateResponse(request, 'connections_create.html', {
+        'title': _('Adding New Generic Connection'),
+        'form': form
+    })
 
 
 def add_ethernet(request):
@@ -339,12 +325,10 @@ def add_ethernet(request):
     else:
         form = EthernetForm()
 
-    return TemplateResponse(
-        request, 'connections_create.html', {
-            'title': _('Adding New Ethernet Connection'),
-            'subsubmenu': subsubmenu,
-            'form': form
-        })
+    return TemplateResponse(request, 'connections_create.html', {
+        'title': _('Adding New Ethernet Connection'),
+        'form': form
+    })
 
 
 def add_pppoe(request):
@@ -359,12 +343,10 @@ def add_pppoe(request):
     else:
         form = PPPoEForm()
 
-    return TemplateResponse(
-        request, 'connections_create.html', {
-            'title': _('Adding New PPPoE Connection'),
-            'subsubmenu': subsubmenu,
-            'form': form
-        })
+    return TemplateResponse(request, 'connections_create.html', {
+        'title': _('Adding New PPPoE Connection'),
+        'form': form
+    })
 
 
 def add_wifi(request, ssid=None, interface_name=None):
@@ -396,12 +378,10 @@ def add_wifi(request, ssid=None, interface_name=None):
         else:
             form = WifiForm()
 
-    return TemplateResponse(
-        request, 'connections_create.html', {
-            'title': _('Adding New Wi-Fi Connection'),
-            'subsubmenu': subsubmenu,
-            'form': form
-        })
+    return TemplateResponse(request, 'connections_create.html', {
+        'title': _('Adding New Wi-Fi Connection'),
+        'form': form
+    })
 
 
 def delete(request, uuid):
@@ -416,9 +396,10 @@ def delete(request, uuid):
             messages.success(request,
                              _('Connection {name} deleted.').format(name=name))
         except network.ConnectionNotFound:
-            messages.error(request,
-                           _('Failed to delete connection: '
-                             'Connection not found.'))
+            messages.error(
+                request,
+                _('Failed to delete connection: '
+                  'Connection not found.'))
 
         return redirect(reverse_lazy('networks:index'))
 
@@ -426,13 +407,58 @@ def delete(request, uuid):
         connection = network.get_connection(uuid)
         name = connection.get_id()
     except network.ConnectionNotFound:
-        messages.error(request,
-                       _('Failed to delete connection: '
-                         'Connection not found.'))
+        messages.error(
+            request, _('Failed to delete connection: '
+                       'Connection not found.'))
         return redirect(reverse_lazy('networks:index'))
 
     return TemplateResponse(request, 'connections_delete.html', {
         'title': _('Delete Connection'),
-        'subsubmenu': subsubmenu,
         'name': name
     })
+
+
+def router_configuration_help_page(request):
+    """
+    Show the router configuration wizard page/form.
+    Used both for fistboot step and same networks page.
+    """
+    is_firstboot = True \
+        if 'firstboot' in request.build_absolute_uri() else False
+
+    if request.method == 'POST' and request.POST['router_config']:
+        form = RouterConfigurationWizardForm(request.POST)
+        if form.is_valid():
+            logger.info('Updating router configuration setup with value: %s' %
+                        request.POST['router_config'])
+            kvstore.set(
+                networks.ROUTER_CONFIGURATION_TYPE_KEY,
+                request.POST['router_config']
+            )
+        if is_firstboot:
+            resp = reverse_lazy(first_boot.next_step())
+        else:
+            resp = reverse_lazy('networks:index')
+            messages.success(request, _('Router configuration type saved.'))
+
+        return redirect(resp)
+
+    else:
+        html = "router_configuration_update.html"
+        initial = {
+            "router_config": kvstore.get_default(
+                networks.ROUTER_CONFIGURATION_TYPE_KEY, 'dmz'),
+        }
+        template_kwargs = {
+            'form': RouterConfigurationWizardForm(initial=initial),
+        }
+        if is_firstboot:
+            html = "router_configuration_firstboot.html"
+
+            # mark step done on firstboot visit to get the next_step
+            first_boot.mark_step_done('router_setup_wizard')
+            template_kwargs.update({
+                'first_boot_next_step': reverse_lazy(first_boot.next_step()),
+            })
+
+        return TemplateResponse(request, html, template_kwargs)
