@@ -21,16 +21,16 @@ FreedomBox app to configure OpenVPN server.
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
 
-from .manifest import backup # noqa, pylint: disable=unused-import
+from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
-version = 3
+version = 4
 
 managed_services = ['openvpn-server@freedombox']
 
@@ -38,6 +38,8 @@ managed_packages = ['openvpn', 'easy-rsa']
 
 name = _('OpenVPN')
 
+icon_filename = 'openvpn'
+
 short_description = _('Virtual Private Network')
 
 description = [
@@ -57,6 +59,8 @@ port_forwarding_info = [('UDP', 1194)]
 
 app = None
 
+clients = clients
+
 
 class OpenVPNApp(app_module.App):
     """FreedomBox app for OpenVPN."""
@@ -77,7 +81,7 @@ class OpenVPNApp(app_module.App):
                         link=reverse_lazy('openvpn:profile'))
         shortcut = frontpage.Shortcut(
             'shortcut-openvpn', name, short_description=short_description,
-            icon='openvpn', description=description + [download_profile],
+            icon=icon_filename, description=description + [download_profile],
             configure_url=reverse_lazy('openvpn:index'), login_required=True)
         self.add(shortcut)
 
@@ -85,7 +89,8 @@ class OpenVPNApp(app_module.App):
                             is_external=True)
         self.add(firewall)
 
-        daemon = Daemon('daemon-openvpn', managed_services[0])
+        daemon = Daemon('daemon-openvpn', managed_services[0],
+                        listen_ports=[(1194, 'udp4'), (1194, 'udp6')])
         self.add(daemon)
 
 
@@ -111,8 +116,3 @@ def setup(helper, old_version=None):
 def is_setup():
     """Return whether the service is running."""
     return actions.superuser_run('openvpn', ['is-setup']).strip() == 'true'
-
-
-def diagnose():
-    """Run diagnostics and return the results."""
-    return [action_utils.diagnose_port_listening(1194, 'udp4')]
