@@ -24,6 +24,5 @@ from django.utils.translation import ugettext_lazy as _
 
 class OpenVpnForm(forms.Form):  # pylint: disable=W0232
     """OpenVPN configuration form."""
-    enabled = forms.BooleanField(
-        label=_('Enable OpenVPN server'),
-        required=False)
+    enabled = forms.BooleanField(label=_('Enable OpenVPN server'),
+                                 required=False)
