@@ -58,12 +58,19 @@ def index(request):
 
     return TemplateResponse(
         request, 'openvpn.html', {
-            'title': openvpn.name,
+            'app_id': 'openvpn',
+            'clients': openvpn.clients,
+            'name': openvpn.name,
             'description': openvpn.description,
             'manual_page': openvpn.manual_page,
             'port_forwarding_info': openvpn.port_forwarding_info,
             'status': status,
-            'form': form
+            'form': form,
+            'show_status_block': True,
+            'is_running': status['is_running'],
+            'has_diagnostics': True,
+            'is_enabled': status['enabled'],
+            'icon_filename': openvpn.icon_filename
         })
 
 
