@@ -20,19 +20,12 @@ URLs for the PageKite module
 
 from django.conf.urls import url
 
-from .views import StandardServiceView, CustomServiceView, ConfigurationView, \
-    DeleteServiceView, FirstBootView, first_boot_skip
+from .views import (ConfigurationView, AddCustomServiceView, DeleteServiceView)
 
 urlpatterns = [
     url(r'^sys/pagekite/$', ConfigurationView.as_view(), name='index'),
-    url(r'^sys/pagekite/services/standard/$', StandardServiceView.as_view(),
-        name='standard-services'),
-    url(r'^sys/pagekite/services/custom/$', CustomServiceView.as_view(),
-        name='custom-services'),
+    url(r'^sys/pagekite/services/custom/add/$', AddCustomServiceView.as_view(),
+        name='add-custom-service'),
     url(r'^sys/pagekite/services/custom/delete/$', DeleteServiceView.as_view(),
         name='delete-custom-service'),
-    url(r'^sys/pagekite/firstboot/$', FirstBootView.as_view(),
-        name='firstboot'),
-    url(r'^sys/pagekite/firstboot/skip/$', first_boot_skip,
-        name='firstboot-skip'),
 ]
