@@ -20,7 +20,7 @@ URLs for the quassel module.
 
 from django.conf.urls import url
 
-from plinth.modules.quassel import QuasselAppView
+from .views import QuasselAppView
 
 urlpatterns = [
     url(r'^apps/quassel/$', QuasselAppView.as_view(), name='index'),
