@@ -26,7 +26,7 @@ import augeas
 from apt.cache import Cache
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
@@ -34,7 +34,7 @@ from plinth.modules.apache.components import Uwsgi, Webserver
 from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
 
-from .manifest import backup, clients # noqa, pylint: disable=unused-import
+from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
 version = 2
 
@@ -44,6 +44,8 @@ managed_packages = ['radicale', 'uwsgi', 'uwsgi-plugin-python3']
 
 name = _('Radicale')
 
+icon_filename = 'radicale'
+
 short_description = _('Calendar and Addressbook')
 
 description = [
@@ -88,7 +90,7 @@ class RadicaleApp(app_module.App):
 
         shortcut = frontpage.Shortcut('shortcut-radicale', name,
                                       short_description=short_description,
-                                      icon='radicale', url='/radicale/',
+                                      icon=icon_filename, url='/radicale/',
                                       clients=clients, login_required=True)
         self.add(shortcut)
 
@@ -96,7 +98,8 @@ class RadicaleApp(app_module.App):
                             is_external=True)
         self.add(firewall)
 
-        webserver = RadicaleWebserver('webserver-radicale', None)
+        webserver = RadicaleWebserver('webserver-radicale', None,
+                                      urls=['https://{host}/radicale'])
         self.add(webserver)
 
         uwsgi = RadicaleUwsgi('uwsgi-radicale', 'radicale')
@@ -108,7 +111,6 @@ class RadicaleApp(app_module.App):
 
 class RadicaleWebserver(Webserver):
     """Webserver enable/disable behavior specific for radicale."""
-
     @property
     def web_name(self):
         """Return web configuration name based on radicale version."""
@@ -125,7 +127,6 @@ class RadicaleWebserver(Webserver):
 
 class RadicaleUwsgi(Uwsgi):
     """uWSGI enable/disable behavior specific for radicale."""
-
     def is_enabled(self):
         """Return whether the uWSGI configuration is enabled if version>=2."""
         package_version = get_package_version()
@@ -150,7 +151,6 @@ class RadicaleUwsgi(Uwsgi):
 
 class RadicaleDaemon(Daemon):
     """Daemon enable/disable behavior specific for radicale."""
-
     @staticmethod
     def _is_old_radicale():
         """Return whether radicale is less than version 2."""
@@ -249,8 +249,8 @@ def disable():
 
 def load_augeas():
     """Prepares the augeas."""
-    aug = augeas.Augeas(
-        flags=augeas.Augeas.NO_LOAD + augeas.Augeas.NO_MODL_AUTOLOAD)
+    aug = augeas.Augeas(flags=augeas.Augeas.NO_LOAD +
+                        augeas.Augeas.NO_MODL_AUTOLOAD)
 
     # INI file lens
     aug.set('/augeas/load/Puppet/lens', 'Puppet.lns')
@@ -272,14 +272,3 @@ def get_rights_value():
             value = 'owner_only'
 
     return value
-
-
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.extend(
-        action_utils.diagnose_url_on_all('https://{host}/radicale',
-                                         check_certificate=False))
-
-    return results
