@@ -34,10 +34,10 @@ class RadicaleAppView(AppView):
     clients = radicale.clients
     name = radicale.name
     description = description
-    diagnostics_module_name = 'radicale'
     form_class = RadicaleForm
     app_id = 'radicale'
     manual_page = radicale.manual_page
+    icon_filename = radicale.icon_filename
 
     def get_initial(self):
         """Return the values to fill in the form."""
