@@ -20,13 +20,13 @@ FreedomBox app to configure Roundcube.
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import frontpage, menu
 from plinth.modules.apache.components import Webserver
 from plinth.modules.firewall.components import Firewall
 
-from .manifest import backup, clients # noqa, pylint: disable=unused-import
+from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
 version = 1
 
@@ -34,6 +34,8 @@ managed_packages = ['sqlite3', 'roundcube', 'roundcube-sqlite3']
 
 name = _('Roundcube')
 
+icon_filename = 'roundcube'
+
 short_description = _('Email Client')
 
 description = [
@@ -42,8 +44,8 @@ description = [
       'full functionality you expect from an email client, including '
       'MIME support, address book, folder manipulation, message '
       'searching and spell checking.'),
-    _('You can access Roundcube from <a href="/roundcube">'
-      '/roundcube</a>. Provide the username and password of the email '
+    _('You can access Roundcube from <a href="/roundcube" data-turbolinks='
+      '"false">/roundcube</a>. Provide the username and password of the email '
       'account you wish to access followed by the domain name of the '
       'IMAP server for your email provider, like <code>imap.example.com'
       '</code>.  For IMAP over SSL (recommended), fill the server field '
@@ -78,7 +80,7 @@ class RoundcubeApp(app_module.App):
 
         shortcut = frontpage.Shortcut('shortcut-roundcube', name,
                                       short_description=short_description,
-                                      icon='roundcube', url='/roundcube/',
+                                      icon=icon_filename, url='/roundcube/',
                                       clients=clients, login_required=True)
         self.add(shortcut)
 
@@ -86,7 +88,8 @@ class RoundcubeApp(app_module.App):
                             ports=['http', 'https'], is_external=True)
         self.add(firewall)
 
-        webserver = Webserver('webserver-roundcube', 'roundcube')
+        webserver = Webserver('webserver-roundcube', 'roundcube',
+                              urls=['https://{host}/roundcube'])
         self.add(webserver)
 
 
@@ -106,14 +109,3 @@ def setup(helper, old_version=None):
     helper.install(managed_packages)
     helper.call('post', actions.superuser_run, 'roundcube', ['setup'])
     helper.call('post', app.enable)
-
-
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.extend(
-        action_utils.diagnose_url_on_all('https://{host}/roundcube',
-                                         check_certificate=False))
-
-    return results
