@@ -27,8 +27,8 @@ urlpatterns = [
     url(
         r'^apps/roundcube/$',
         AppView.as_view(app_id='roundcube', name=roundcube.name,
-                        diagnostics_module_name='roundcube',
                         description=roundcube.description,
-                        show_status_block=False,
-                        manual_page=roundcube.manual_page), name='index'),
+                        show_status_block=False, clients=roundcube.clients,
+                        manual_page=roundcube.manual_page,
+                        icon_filename=roundcube.icon_filename), name='index'),
 ]
