@@ -22,14 +22,15 @@ import os
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import frontpage, menu
 from plinth.modules.apache.components import Uwsgi, Webserver
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.users import register_group
 
-from .manifest import PUBLIC_ACCESS_SETTING_FILE, backup, clients # noqa, pylint: disable=unused-import
+from .manifest import (PUBLIC_ACCESS_SETTING_FILE,  # noqa, pylint: disable=unused-import
+                       backup, clients)
 
 clients = clients
 
@@ -39,6 +40,8 @@ managed_packages = ['searx', 'uwsgi', 'uwsgi-plugin-python3']
 
 name = _('Searx')
 
+icon_filename = 'searx'
+
 short_description = _('Web Search')
 
 description = [
@@ -69,7 +72,7 @@ class SearxApp(app_module.App):
 
         shortcut = frontpage.Shortcut(
             'shortcut-searx', name, short_description=short_description,
-            icon='searx', url='/searx/', clients=clients,
+            icon=icon_filename, url='/searx/', clients=clients,
             login_required=(not is_public_access_enabled()),
             allowed_groups=[group[0]])
         self.add(shortcut)
@@ -78,7 +81,8 @@ class SearxApp(app_module.App):
                             is_external=True)
         self.add(firewall)
 
-        webserver = Webserver('webserver-searx', 'searx-freedombox')
+        webserver = Webserver('webserver-searx', 'searx-freedombox',
+                              urls=['https://{host}/searx/'])
         self.add(webserver)
 
         webserver = SearxWebserverAuth('webserver-searx-auth',
@@ -97,7 +101,6 @@ class SearxApp(app_module.App):
 
 class SearxWebserverAuth(Webserver):
     """Component to handle Searx authentication webserver configuration."""
-
     def is_enabled(self):
         """Return if configuration is enabled or public access is enabled."""
         return is_public_access_enabled() or super().is_enabled()
@@ -141,17 +144,6 @@ def is_public_access_enabled():
     return os.path.exists(PUBLIC_ACCESS_SETTING_FILE)
 
 
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.extend(
-        action_utils.diagnose_url_on_all('https://{host}/searx/',
-                                         check_certificate=False))
-
-    return results
-
-
 def enable_public_access():
     """Allow Searx app to be accessed by anyone with access."""
     actions.superuser_run('searx', ['enable-public-access'])
