@@ -33,11 +33,11 @@ class SearxAppView(views.AppView):
     clients = searx.clients
     name = searx.name
     description = searx.description
-    diagnostics_module_name = 'searx'
     app_id = 'searx'
     form_class = SearxForm
     show_status_block = False
     manual_page = searx.manual_page
+    icon_filename = searx.icon_filename
 
     def get_initial(self):
         """Return the status of the service to fill in the form."""
