@@ -18,9 +18,11 @@
 FreedomBox app for security configuration.
 """
 
+import re
 import subprocess
 from collections import defaultdict
 
+import requests
 from django.utils.translation import ugettext_lazy as _
 
 from plinth import actions
@@ -112,8 +114,8 @@ def set_restricted_access(enabled):
     actions.superuser_run('security', [action])
 
 
-def get_vulnerability_counts():
-    """Return number of security vulnerabilities for each app"""
+def get_apps_report():
+    """Return a security report for each app"""
     lines = subprocess.check_output(['debsecan']).decode().split('\n')
     cves = defaultdict(set)
     for line in lines:
@@ -121,19 +123,44 @@ def get_vulnerability_counts():
             (label, package, *_) = line.split()
             cves[label].add(package)
 
+    try:
+        past_cves = requests.get(
+            'https://security-tracker.debian.org/tracker/data/json').json()
+    except Exception:
+        past_cves = None
+
+    service_exposure_lines = subprocess.check_output(
+        ['systemd-analyze', 'security']).decode().strip().split('\n')
+    service_exposure_lines.pop(0)
+    sandbox_coverage = {}
+    for line in service_exposure_lines:
+        fields = line.split()
+        name = re.sub(r'\.service$', '', fields[0])
+        score = round(100 - float(fields[1]) * 10)
+        sandbox_coverage[name] = score
+
     apps = {
         'freedombox': {
             'name': 'freedombox',
             'packages': {'freedombox'},
-            'count': 0,
+            'vulns': 0,
+            'past_vulns': 0 if past_cves else None,
         }
     }
+    if past_cves and 'freedombox' in past_cves:
+        apps['freedombox']['past_vulns'] = len(past_cves['freedombox'])
+
     for module_name, module in module_loader.loaded_modules.items():
         try:
             packages = module.managed_packages
         except AttributeError:
             continue  # app has no managed packages
 
+        try:
+            services = module.managed_services
+        except AttributeError:
+            services = None
+
         # filter out apps not setup yet
         if module.setup_helper.get_state() == 'needs-setup':
             continue
@@ -141,12 +168,58 @@ def get_vulnerability_counts():
         apps[module_name] = {
             'name': module_name,
             'packages': set(packages),
-            'count': 0,
+            'vulns': 0,
+            'past_vulns': 0 if past_cves else None,
+            'sandboxed': None,
         }
 
+        for package in packages:
+            if past_cves and package in past_cves:
+                apps[module_name]['past_vulns'] += len(past_cves[package])
+
+        if services:
+            apps[module_name]['sandboxed'] = False
+            for service in services:
+                if _get_service_is_sandboxed(service):
+                    apps[module_name]['sandboxed'] = True
+                    apps[module_name][
+                        'sandbox_coverage'] = sandbox_coverage.get(service)
+
     for cve_packages in cves.values():
         for app_ in apps.values():
             if cve_packages & app_['packages']:
-                app_['count'] += 1
+                app_['vulns'] += 1
 
     return apps
+
+
+def _get_service_is_sandboxed(service):
+    """Return whether service is sandboxed."""
+    lines = subprocess.check_output([
+        'systemctl',
+        'show',
+        service,
+        '--property=ProtectSystem',
+        '--property=ProtectHome',
+        '--property=PrivateTmp',
+        '--property=PrivateDevices',
+        '--property=PrivateNetwork',
+        '--property=PrivateUsers',
+        '--property=PrivateMounts',
+    ]).decode().strip().split('\n')
+    pairs = [line.partition('=')[::2] for line in lines]
+    properties = {name: value for name, value in pairs}
+    if properties['ProtectSystem'] in ['yes', 'full', 'strict']:
+        return True
+
+    if properties['ProtectHome'] in ['yes', 'read-only', 'tmpfs']:
+        return True
+
+    for name in [
+            'PrivateTmp', 'PrivateDevices', 'PrivateNetwork', 'PrivateUsers',
+            'PrivateMounts'
+    ]:
+        if properties[name] == 'yes':
+            return True
+
+    return False
