@@ -20,8 +20,7 @@ Application manifest for security.
 
 from plinth.modules.backups.api import validate as validate_backup
 
-backup = validate_backup({
-    'config': {
+backup = validate_backup(
+    {'config': {
         'files': ['/etc/security/access.d/50freedombox.conf']
-    }
-})
+    }})
