@@ -43,21 +43,11 @@ def index(request):
     else:
         form = SecurityForm(initial=status, prefix='security')
 
-    vulnerability_counts = security.get_vulnerability_counts()
-    return TemplateResponse(
-        request, 'security.html', {
-            'name':
-                _('Security'),
-            'manual_page':
-                security.manual_page,
-            'form':
-                form,
-            'freedombox_vulns':
-                vulnerability_counts.pop('freedombox'),
-            'apps_vulns':
-                sorted(vulnerability_counts.values(),
-                       key=lambda app: app['name']),
-        })
+    return TemplateResponse(request, 'security.html', {
+        'name': _('Security'),
+        'manual_page': security.manual_page,
+        'form': form,
+    })
 
 
 def get_status(request):
@@ -86,3 +76,17 @@ def _apply_changes(request, old_status, new_status):
             actions.superuser_run('service', ['enable', 'fail2ban'])
         else:
             actions.superuser_run('service', ['disable', 'fail2ban'])
+
+
+def report(request):
+    """Serve the security report page"""
+    apps_report = security.get_apps_report()
+    return TemplateResponse(
+        request, 'security_report.html', {
+            'title':
+                _('Security Report'),
+            'freedombox_report':
+                apps_report.pop('freedombox'),
+            'apps_report':
+                sorted(apps_report.values(), key=lambda app: app['name']),
+        })
