@@ -37,10 +37,10 @@ short_description = _('Bookmarks')
 
 description = [
     _('Shaarli allows you to save and share bookmarks.'),
-    _('When enabled, Shaarli will be available from <a href="/shaarli">'
-      '/shaarli</a> path on the web server. Note that Shaarli only supports a '
-      'single user account, which you will need to setup on the initial '
-      'visit.'),
+    _('When enabled, Shaarli will be available from <a href="/shaarli" '
+      'data-turbolinks="false">/shaarli</a> path on the web server. Note that '
+      'Shaarli only supports a single user account, which you will need to '
+      'setup on the initial visit.'),
 ]
 
 clients = clients
