@@ -21,19 +21,21 @@ FreedomBox app to configure Shadowsocks.
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
 
-from .manifest import backup # noqa, pylint: disable=unused-import
+from .manifest import backup  # noqa, pylint: disable=unused-import
 
 version = 1
 
 name = _('Shadowsocks')
 
+icon_filename = 'shadowsocks'
+
 short_description = _('Socks5 Proxy')
 
 managed_services = ['shadowsocks-libev-local@freedombox']
@@ -74,7 +76,7 @@ class ShadowsocksApp(app_module.App):
 
         shortcut = frontpage.Shortcut(
             'shortcut-shadowsocks', name, short_description=short_description,
-            icon='shadowsocks', description=description,
+            icon=icon_filename, description=description,
             configure_url=reverse_lazy('shadowsocks:index'),
             login_required=True)
         self.add(shortcut)
@@ -84,7 +86,8 @@ class ShadowsocksApp(app_module.App):
                             is_external=False)
         self.add(firewall)
 
-        daemon = Daemon('daemon-shadowsocks', managed_services[0])
+        daemon = Daemon('daemon-shadowsocks', managed_services[0],
+                        listen_ports=[(1080, 'tcp4'), (1080, 'tcp6')])
         self.add(daemon)
 
 
@@ -103,13 +106,3 @@ def setup(helper, old_version=None):
     helper.install(managed_packages)
     helper.call('post', actions.superuser_run, 'shadowsocks', ['setup'])
     helper.call('post', app.enable)
-
-
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.append(action_utils.diagnose_port_listening(1080, 'tcp4'))
-    results.append(action_utils.diagnose_port_listening(1080, 'tcp6'))
-
-    return results
