@@ -20,7 +20,7 @@ URLs for the Secure Shell Server module.
 
 from django.conf.urls import url
 
-from plinth.modules.ssh import SshAppView
+from plinth.modules.ssh.views import SshAppView
 
 urlpatterns = [
     url(r'^sys/ssh/$', SshAppView.as_view(), name='index'),
