@@ -25,8 +25,8 @@ from stronghold.decorators import public
 from plinth.utils import non_admin_view
 
 urlpatterns = [
-    url(r'^accounts/sso/login/$',
-        public(SSOLoginView.as_view()), name='sso-login'),
+    url(r'^accounts/sso/login/$', public(SSOLoginView.as_view()),
+        name='sso-login'),
     url(r'^accounts/sso/refresh/$', non_admin_view(refresh),
         name='sso-refresh'),
 ]
