@@ -17,20 +17,24 @@
 """
 FreedomBox app to manage storage.
 """
+
 import logging
 import subprocess
 
 import psutil
 from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext_noop
 
 from plinth import actions
 from plinth import app as app_module
-from plinth import cfg, menu, utils
+from plinth import cfg, glib, menu, utils
 from plinth.daemon import Daemon
-from plinth.errors import PlinthError
+from plinth.errors import ActionError, PlinthError
 from plinth.utils import format_lazy, import_from_gi
 
-version = 3
+from .manifest import backup  # noqa, pylint: disable=unused-import
+
+version = 4
 
 name = _('Storage')
 
@@ -70,6 +74,10 @@ class StorageApp(app_module.App):
         daemon = Daemon('daemon-udiskie', managed_services[0])
         self.add(daemon)
 
+        # Check every hour for low disk space, every 3 minutes in debug mode
+        interval = 180 if cfg.develop else 3600
+        glib.schedule(interval, warn_about_low_disk_space)
+
 
 def init():
     """Initialize the module."""
@@ -79,15 +87,15 @@ def init():
 
 
 def get_disks():
-    """Returns list of disks by combining information from df and lsblk."""
-    disks = _get_disks_from_udisks()
-    disks_from_df = _get_disks_from_df()
+    """Returns list of disks by combining information from df and udisks."""
+    disks = _get_disks_from_df()
+    disks_from_udisks = _get_disks_from_udisks()
 
-    # Add size info from df to the disks from udisks based on mount point.
-    for disk_from_udisks in disks:
-        for disk_from_df in disks_from_df:
+    # Add info from udisks to the disks from df based on mount point.
+    for disk_from_df in disks:
+        for disk_from_udisks in disks_from_udisks:
             if disk_from_udisks['mount_point'] == disk_from_df['mount_point']:
-                disk_from_udisks.update(disk_from_df)
+                disk_from_df.update(disk_from_udisks)
 
     return sorted(disks, key=lambda disk: disk['device'])
 
@@ -136,7 +144,7 @@ def _get_disks_from_df():
     disks = []
     for line in output.splitlines()[1:]:
         parts = line.split(maxsplit=6)
-        keys = ('device', 'file_system_type', 'size', 'used', 'free',
+        keys = ('device', 'filesystem_type', 'size', 'used', 'free',
                 'percent_used', 'mount_point')
         disk = dict(zip(keys, parts))
         disk['percent_used'] = int(disk['percent_used'].rstrip('%'))
@@ -146,6 +154,8 @@ def _get_disks_from_df():
         disk['size_str'] = format_bytes(disk['size'])
         disk['used_str'] = format_bytes(disk['used'])
         disk['free_str'] = format_bytes(disk['free'])
+        disk['label'] = None
+        disk['is_removable'] = None
         disks.append(disk)
 
     return disks
@@ -191,8 +201,9 @@ def is_expandable(device):
         return False
 
     try:
-        output = actions.superuser_run(
-            'storage', ['is-partition-expandable', device], log_error=False)
+        output = actions.superuser_run('storage',
+                                       ['is-partition-expandable', device],
+                                       log_error=False)
     except actions.ActionError:
         return False
 
@@ -274,8 +285,63 @@ def get_error_message(error):
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages, skip_recommends=True)
+    helper.call('post', actions.superuser_run, 'storage', ['setup'])
     helper.call('post', app.enable)
     disks = get_disks()
     root_device = get_root_device(disks)
     if is_expandable(root_device):
-        expand_partition(root_device)
+        try:
+            expand_partition(root_device)
+        except ActionError:
+            pass
+
+
+def warn_about_low_disk_space(request):
+    """Warn about insufficient space on root partition."""
+    from plinth.notification import Notification
+
+    try:
+        root_info = get_disk_info('/')
+    except PlinthError as exception:
+        logger.exception('Error getting information about root partition: %s',
+                         exception)
+        return
+
+    show = False
+    if root_info['percent_used'] > 90 or root_info['free_gib'] < 1:
+        severity = 'error'
+        show = True
+    elif root_info['percent_used'] > 75 or root_info['free_gib'] < 2:
+        severity = 'warning'
+        show = True
+
+    if not show:
+        try:
+            Notification.get('storage-low-disk-space').delete()
+        except KeyError:
+            pass
+    else:
+        # Translators: xgettext:no-python-format
+        message = ugettext_noop(
+            'Low space on system partition: {percent_used}% used, '
+            '{free_space} free.')
+        title = ugettext_noop('Low disk space')
+        data = {
+            'app_icon': 'fa-hdd-o',
+            'app_name': ugettext_noop('Storage'),
+            'percent_used': root_info['percent_used'],
+            'free_space': format_bytes(root_info['free_bytes'])
+        }
+        actions = [{
+            'type': 'link',
+            'class': 'primary',
+            'text': 'Go to {app_name}',
+            'url': 'storage:index'
+        }, {
+            'type': 'dismiss'
+        }]
+        Notification.update_or_create(id='storage-low-disk-space',
+                                      app_id='storage', severity=severity,
+                                      title=title, message=message,
+                                      actions=actions, data=data,
+                                      group='admin')
