@@ -20,7 +20,7 @@ FreedomBox app to configure Syncthing.
 
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
@@ -29,7 +29,7 @@ from plinth.modules.firewall.components import Firewall
 from plinth.modules.users import register_group
 from plinth.utils import format_lazy
 
-from .manifest import backup, clients # noqa, pylint: disable=unused-import
+from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
 version = 2
 
@@ -39,6 +39,8 @@ managed_packages = ['syncthing']
 
 name = _('Syncthing')
 
+icon_filename = 'syncthing'
+
 short_description = _('File Synchronization')
 
 description = [
@@ -54,9 +56,6 @@ description = [
           'user\'s set of devices may be synchronized with a distinct set of '
           'folders.  The web interface on {box_name} is only available for '
           'users belonging to the "admin" group.'), box_name=_(cfg.box_name)),
-    _('When enabled, Syncthing\'s web interface will be available from '
-      '<a href="/syncthing/">/syncthing</a>.  Desktop and mobile clients are '
-      'also <a href="https://syncthing.net/">available</a>.'),
 ]
 
 clients = clients
@@ -81,10 +80,11 @@ class SyncthingApp(app_module.App):
                               parent_url_name='apps')
         self.add(menu_item)
 
-        shortcut = frontpage.Shortcut(
-            'shortcut-syncthing', name, short_description=short_description,
-            icon='syncthing', url='/syncthing/', clients=clients,
-            login_required=True, allowed_groups=[group[0]])
+        shortcut = frontpage.Shortcut('shortcut-syncthing', name,
+                                      short_description=short_description,
+                                      icon=icon_filename, url='/syncthing/',
+                                      clients=clients, login_required=True,
+                                      allowed_groups=[group[0]])
         self.add(shortcut)
 
         firewall = Firewall('firewall-syncthing-web', name,
@@ -95,7 +95,8 @@ class SyncthingApp(app_module.App):
                             ports=['syncthing'], is_external=True)
         self.add(firewall)
 
-        webserver = Webserver('webserver-syncthing', 'syncthing-plinth')
+        webserver = Webserver('webserver-syncthing', 'syncthing-plinth',
+                              urls=['https://{host}/syncthing/'])
         self.add(webserver)
 
         daemon = Daemon('daemon-syncthing', managed_services[0])
@@ -122,14 +123,3 @@ def setup(helper, old_version=None):
 
     if old_version == 1 and app.is_enabled():
         app.get_component('firewall-syncthing-ports').enable()
-
-
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.extend(
-        action_utils.diagnose_url_on_all('https://{host}/syncthing/',
-                                         check_certificate=False))
-
-    return results
