@@ -18,20 +18,16 @@
 URLs for the Tahoe-LAFS module.
 """
 
-from . import views
-
 from django.conf.urls import url
 
-from .views import TahoeSetupView, TahoeServiceView
-
+from . import views
+from .views import TahoeAppView, TahoeSetupView
 
 urlpatterns = [
-    url(r'^apps/tahoe-lafs/setup$', TahoeSetupView.as_view(),
-        name='setup'),
-    url(r'^apps/tahoe-lafs/add_introducer$', views.add_introducer,
-        name="add-introducer"),
-    url(r'^apps/tahoe-lafs/remove_introducer/(?P<introducer>[0-9a-zA-Z_]+)$',
-        views.remove_introducer, name="remove-introducer"),
-    url(r'^apps/tahoe-lafs/$', TahoeServiceView.as_view(),
-        name='index')
+    url(r'^apps/tahoe/setup/$', TahoeSetupView.as_view(), name='setup'),
+    url(r'^apps/tahoe/add_introducer/$', views.add_introducer,
+        name='add-introducer'),
+    url(r'^apps/tahoe/remove_introducer/(?P<introducer>[0-9a-zA-Z_]+)/$',
+        views.remove_introducer, name='remove-introducer'),
+    url(r'^apps/tahoe/$', TahoeAppView.as_view(), name='index')
 ]
