@@ -18,6 +18,8 @@
 Tests for Tor module.
 """
 
+from unittest.mock import patch
+
 import pytest
 from django.core.exceptions import ValidationError
 
@@ -26,7 +28,6 @@ from plinth.modules.tor import forms, utils
 
 class TestTor:
     """Test cases for testing the Tor module."""
-
     @staticmethod
     @pytest.mark.usefixtures('needs_root')
     def test_is_apt_transport_tor_enabled():
@@ -36,8 +37,9 @@ class TestTor:
         utils.is_apt_transport_tor_enabled()
 
     @staticmethod
+    @patch('plinth.modules.tor.app')
     @pytest.mark.usefixtures('needs_root', 'load_cfg')
-    def test_get_status():
+    def test_get_status(_app):
         """Test that get_status does not raise any unhandled exceptions.
 
         This should work regardless of whether tor is installed, or
@@ -48,7 +50,6 @@ class TestTor:
 
 class TestTorForm:
     """Test whether Tor configration form works."""
-
     @staticmethod
     def test_bridge_validator():
         """Test upstream bridges' form field validator."""
