@@ -20,6 +20,7 @@ FreedomBox app for configuring Transmission Server.
 
 import json
 import logging
+import os
 import socket
 
 from django.contrib import messages
@@ -38,10 +39,10 @@ class TransmissionAppView(views.AppView):
     clients = transmission.clients
     name = transmission.name
     description = transmission.description
-    diagnostics_module_name = 'transmission'
     form_class = TransmissionForm
     app_id = 'transmission'
     manual_page = transmission.manual_page
+    icon_filename = transmission.icon_filename
 
     def get_initial(self):
         """Get the current settings from Transmission server."""
@@ -49,12 +50,8 @@ class TransmissionAppView(views.AppView):
         configuration = actions.superuser_run('transmission',
                                               ['get-configuration'])
         configuration = json.loads(configuration)
-        status.update({
-            key.translate(str.maketrans({
-                '-': '_'
-            })): value
-            for key, value in configuration.items()
-        })
+        status['storage_path'] = os.path.normpath(
+            configuration['download-dir'])
         status['hostname'] = socket.gethostname()
 
         return status
@@ -64,13 +61,15 @@ class TransmissionAppView(views.AppView):
         old_status = form.initial
         new_status = form.cleaned_data
 
-        if old_status['download_dir'] != new_status['download_dir']:
-            new_configuration = {
-                'download-dir': new_status['download_dir'],
-            }
+        if new_status['is_enabled'] or not old_status['is_enabled']:
+            if old_status['storage_path'] != new_status['storage_path']:
+                new_configuration = {
+                    'download-dir': new_status['storage_path'],
+                }
 
-            actions.superuser_run('transmission', ['merge-configuration'],
-                                  input=json.dumps(new_configuration).encode())
-            messages.success(self.request, _('Configuration updated'))
+                actions.superuser_run(
+                    'transmission', ['merge-configuration'],
+                    input=json.dumps(new_configuration).encode())
+                messages.success(self.request, _('Configuration updated'))
 
         return super().form_valid(form)
