@@ -21,7 +21,7 @@ FreedomBox app to configure Tiny Tiny RSS.
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext_lazy as _
 
-from plinth import action_utils, actions
+from plinth import actions
 from plinth import app as app_module
 from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
@@ -42,6 +42,8 @@ managed_packages = [
 
 name = _('Tiny Tiny RSS')
 
+icon_filename = 'ttrss'
+
 short_description = _('News Feed Reader')
 
 description = [
@@ -49,13 +51,13 @@ description = [
       'designed to allow reading news from any location, while feeling as '
       'close to a real desktop application as possible.'),
     format_lazy(
-        _('When enabled, Tiny Tiny RSS will be available from <a href="/tt-'
-          'rss">/tt-rss</a> path on the web server. It can be accessed by '
-          'any <a href="{users_url}">user with a {box_name} login</a>.'),
+        _('When enabled, Tiny Tiny RSS can be accessed by any '
+          '<a href="{users_url}">user with a {box_name} login</a>.'),
         box_name=_(cfg.box_name), users_url=reverse_lazy('users:index')),
     format_lazy(
         _('When using a mobile or desktop application for Tiny Tiny RSS, use '
-          'the URL <a href="/tt-rss-app/">/tt-rss-app</a> for connecting.'))
+          'the URL <a href="/tt-rss-app/" data-turbolinks="false">'
+          '/tt-rss-app</a> for connecting.'))
 ]
 
 clients = clients
@@ -79,17 +81,19 @@ class TTRSSApp(app_module.App):
                               'ttrss:index', parent_url_name='apps')
         self.add(menu_item)
 
-        shortcut = frontpage.Shortcut(
-            'shortcut-ttrss', name, short_description=short_description,
-            icon='ttrss', url='/tt-rss', clients=clients, login_required=True,
-            allowed_groups=[group[0]])
+        shortcut = frontpage.Shortcut('shortcut-ttrss', name,
+                                      short_description=short_description,
+                                      icon=icon_filename, url='/tt-rss',
+                                      clients=clients, login_required=True,
+                                      allowed_groups=[group[0]])
         self.add(shortcut)
 
         firewall = Firewall('firewall-ttrss', name, ports=['http', 'https'],
                             is_external=True)
         self.add(firewall)
 
-        webserver = Webserver('webserver-ttrss', 'tt-rss-plinth')
+        webserver = Webserver('webserver-ttrss', 'tt-rss-plinth',
+                              urls=['https://{host}/tt-rss'])
         self.add(webserver)
 
         daemon = Daemon('daemon-ttrss', managed_services[0])
@@ -125,10 +129,9 @@ def force_upgrade(helper, packages):
     if 'tt-rss' not in packages:
         return False
 
-    # tt-rss 17.4 -> 18.12
+    # Allow tt-rss any lower version to upgrade to 19.8.*
     package = packages['tt-rss']
-    if Version(package['current_version']) >= Version('18.12') or \
-       Version(package['new_version']) < Version('18.12'):
+    if Version(package['new_version']) > Version('19.9~'):
         return False
 
     helper.install(['tt-rss'], force_configuration='new')
@@ -136,17 +139,6 @@ def force_upgrade(helper, packages):
     return True
 
 
-def diagnose():
-    """Run diagnostics and return the results."""
-    results = []
-
-    results.extend(
-        action_utils.diagnose_url_on_all('https://{host}/tt-rss',
-                                         check_certificate=False))
-
-    return results
-
-
 def backup_pre(packet):
     """Save database contents."""
     actions.superuser_run('ttrss', ['dump-database'])
