@@ -15,17 +15,19 @@
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 #
 
-import subprocess
+import pwd
+import re
 
+import plinth.forms
 from django import forms
 from django.contrib import auth, messages
 from django.contrib.auth.forms import SetPasswordForm, UserCreationForm
 from django.contrib.auth.models import Group, User
+from django.core import validators
 from django.core.exceptions import ValidationError
+from django.utils.deconstruct import deconstructible
 from django.utils.translation import ugettext as _
 from django.utils.translation import ugettext_lazy
-
-import plinth.forms
 from plinth import actions, module_loader
 from plinth.errors import ActionError
 from plinth.modules import first_boot, users
@@ -61,22 +63,37 @@ class ValidNewUsernameCheckMixin(object):
     def is_valid_new_username(self):
         """Check for username collisions with system users."""
         username = self.cleaned_data['username']
-        try:
-            subprocess.run(['getent', 'passwd', username],
-                           stdout=subprocess.DEVNULL, check=True)
-            # Exit code 0 means that the username is already in use.
+        existing_users = (a.pw_name.lower() for a in pwd.getpwall())
+        if username.lower() in existing_users:
             return False
-        except subprocess.CalledProcessError:
-            pass
 
         for module_name, module in module_loader.loaded_modules.items():
             for reserved_username in getattr(module, 'reserved_usernames', []):
-                if username == reserved_username:
+                if username.lower() == reserved_username.lower():
                     return False
 
         return True
 
 
+@deconstructible
+class UsernameValidator(validators.RegexValidator):
+    """Username validator.
+
+    Compared to django builtin ASCIIUsernameValidator, do not allow
+    '+' characters and no '-' character at the beginning.
+
+    """
+    regex = r'^[\w.@][\w.@-]+\Z'
+    message = ugettext_lazy('Enter a valid username.')
+    flags = re.ASCII
+
+
+USERNAME_FIELD = forms.CharField(
+    max_length=150, validators=[UsernameValidator()],
+    help_text=ugettext_lazy('Required. 150 characters or fewer. English '
+                            'letters, digits and @/./-/_ only.'))
+
+
 class CreateUserForm(ValidNewUsernameCheckMixin,
                      plinth.forms.LanguageSelectionFormMixin,
                      UserCreationForm):
@@ -84,6 +101,7 @@ class CreateUserForm(ValidNewUsernameCheckMixin,
 
     Include options to add user to groups.
     """
+    username = USERNAME_FIELD
     groups = forms.MultipleChoiceField(
         choices=get_group_choices(), label=ugettext_lazy('Permissions'),
         required=False, widget=forms.CheckboxSelectMultiple,
@@ -107,6 +125,11 @@ class CreateUserForm(ValidNewUsernameCheckMixin,
         self.request = request
         super(CreateUserForm, self).__init__(*args, **kwargs)
         self.fields['groups'].choices = get_group_choices()
+        self.fields['username'].widget.attrs.update({
+            'autofocus': 'autofocus',
+            'autocapitalize': 'none',
+            'autocomplete': 'username'
+        })
 
     def save(self, commit=True):
         """Save the user model and create LDAP user if required."""
@@ -145,9 +168,10 @@ class CreateUserForm(ValidNewUsernameCheckMixin,
 class UserUpdateForm(ValidNewUsernameCheckMixin,
                      plinth.forms.LanguageSelectionFormMixin, forms.ModelForm):
     """When user info is changed, also updates LDAP user."""
+    username = USERNAME_FIELD
     ssh_keys = forms.CharField(
-        label=ugettext_lazy('SSH Keys'), required=False, widget=forms.Textarea,
-        help_text=ugettext_lazy(
+        label=ugettext_lazy('Authorized SSH Keys'), required=False,
+        widget=forms.Textarea, help_text=ugettext_lazy(
             'Setting an SSH public key will allow this user to '
             'securely log in to the system without using a '
             'password. You may enter multiple keys, one on each '
@@ -174,6 +198,11 @@ class UserUpdateForm(ValidNewUsernameCheckMixin,
         self.username = username
         super(UserUpdateForm, self).__init__(*args, **kwargs)
         self.is_last_admin_user = get_last_admin_user() == self.username
+        self.fields['username'].widget.attrs.update({
+            'autofocus': 'autofocus',
+            'autocapitalize': 'none',
+            'autocomplete': 'username'
+        })
 
         choices = []
 
@@ -261,6 +290,21 @@ class UserUpdateForm(ValidNewUsernameCheckMixin,
             except ActionError:
                 messages.error(self.request, _('Unable to set SSH keys.'))
 
+            is_active = self.cleaned_data['is_active']
+            if self.initial['is_active'] != is_active:
+                if is_active:
+                    status = 'active'
+                else:
+                    status = 'inactive'
+                try:
+                    actions.superuser_run(
+                        'users',
+                        ['set-user-status',
+                         user.get_username(), status])
+                except ActionError:
+                    messages.error(self.request,
+                                   _('Failed to change user status.'))
+
         return user
 
     def validate_last_admin_user(self, groups):
@@ -284,6 +328,9 @@ class UserChangePasswordForm(SetPasswordForm):
         """Initialize the form with extra request argument."""
         self.request = request
         super(UserChangePasswordForm, self).__init__(*args, **kwargs)
+        self.fields['new_password1'].widget.attrs.update({
+            'autofocus': 'autofocus'
+        })
 
     def save(self, commit=True):
         """Save the user model and change LDAP password as well."""
@@ -303,10 +350,12 @@ class UserChangePasswordForm(SetPasswordForm):
 
 class FirstBootForm(ValidNewUsernameCheckMixin, auth.forms.UserCreationForm):
     """User module first boot step: create a new admin user."""
+    username = USERNAME_FIELD
 
     def __init__(self, *args, **kwargs):
         self.request = kwargs.pop('request')
         super().__init__(*args, **kwargs)
+        self.fields['username'].widget.attrs.update({'autofocus': 'autofocus'})
 
     def save(self, commit=True):
         """Create and log the user in."""
