@@ -23,6 +23,7 @@ it is recommended to run this module with root privileges in a virtual machine.
 
 import pathlib
 import random
+import re
 import string
 import subprocess
 
@@ -62,6 +63,13 @@ def _get_password_hash(username):
     return process.stdout.decode().strip().split()[-1]
 
 
+def _get_samba_users():
+    """Get users from the Samba user database."""
+    stdout = subprocess.check_output(
+        ['tdbdump', '/var/lib/samba/private/passdb.tdb']).decode()
+    return re.findall(r'USER_(.*)\\0', stdout)
+
+
 def _try_login_to_ssh(username, password, returncode=0):
     """Return whether the sshpass returncode matches when trying to
     login to ssh using the given username and password"""
@@ -93,6 +101,8 @@ def fixture_disable_restricted_access(needs_root, load_cfg):
         security.set_restricted_access(False)
         yield
         security.set_restricted_access(True)
+    else:
+        yield
 
 
 @pytest.fixture(name='auto_cleanup_users_groups', autouse=True)
@@ -132,14 +142,15 @@ def _create_user(username=None, groups=None):
     if groups:
         for group in groups:
             _call_action(['add-user-to-group', username, group])
-            _cleanup_groups.add(group)
+            if group != 'admin':
+                _cleanup_groups.add(group)
 
     _cleanup_users.add(username)
     return username, password
 
 
 def _delete_user(username):
-    """Utility to delete an LDAP user"""
+    """Utility to delete an LDAP and Samba user"""
     _call_action(['remove-user', username])
 
 
@@ -175,6 +186,7 @@ def test_create_user():
     username, password = _create_user(groups=['admin', _random_string()])
     # assert_can_login_to_console(username, password)
     assert _try_login_to_ssh(username, password)
+    assert username in _get_samba_users()
     with pytest.raises(subprocess.CalledProcessError):
         _create_user(username)
 
@@ -211,6 +223,7 @@ def test_rename_user():
     new_username = _rename_user(old_username)
     assert _try_login_to_ssh(new_username, password)
     assert _try_login_to_ssh(old_username, password, returncode=5)
+    assert old_username not in _get_samba_users()
 
     new_groups = _get_user_groups(new_username)
     old_users_groups = _get_user_groups(old_username)
@@ -244,6 +257,8 @@ def test_delete_user():
     # Deleted user cannot login to ssh
     assert _try_login_to_ssh(username, password, returncode=5)
 
+    assert username not in _get_samba_users()
+
 
 def test_delete_non_existent_user():
     """Deleting a non-existent user should fail."""
