@@ -43,7 +43,6 @@ _force_upgrader = None
 
 class Helper(object):
     """Helper routines for modules to show progress."""
-
     def __init__(self, module_name, module):
         """Initialize the object."""
         self.module_name = module_name
@@ -421,11 +420,9 @@ class ForceUpgrader():
 
     class TemporaryFailure(Exception):
         """Raised when upgrade fails but can be tried again immediately."""
-
     class PermanentFailure(Exception):
         """Raised when upgrade fails and there is nothing more we wish to do.
         """
-
     def __init__(self):
         """Initialize the force upgrader."""
         if plinth.cfg.develop:
@@ -502,7 +499,7 @@ class ForceUpgrader():
 
         apps = self._get_list_of_apps_to_force_upgrade()
         logger.info('Apps needing conffile upgrades: %s',
-                    ', '.join([str(app.name) for app in apps]))
+                    ', '.join([str(app.name) for app in apps]) or 'None')
 
         need_retry = False
         for app, packages in apps.items():
