@@ -14,16 +14,18 @@
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-
 """
 Test module for network configuration utilities.
 """
 
 import copy
+import threading
 import time
 
 import pytest
 
+from plinth.utils import import_from_gi
+
 ethernet_settings = {
     'common': {
         'type': '802-3-ethernet',
@@ -84,6 +86,32 @@ pppoe_settings = {
 }
 
 
+@pytest.fixture(autouse=True, scope='module')
+def fixture_network_module_init():
+    """Initialize network module in a separate thread."""
+    from plinth import network as network_module
+    glib = import_from_gi('GLib', '2.0')
+    main_loop = glib.MainLoop()
+
+    def main_loop_runner():
+        """Initialize the network module and run glib main loop until quit."""
+        network_module.init()
+        main_loop.run()
+
+    thread = threading.Thread(target=main_loop_runner)
+    thread.start()
+
+    while not network_module._client:
+        time.sleep(0.1)
+
+    yield
+
+    if main_loop:
+        main_loop.quit()
+
+    thread.join()
+
+
 @pytest.fixture(name='network')
 def fixture_network(needs_root):
     """Return the network module. Load it conservatively."""
@@ -146,6 +174,7 @@ def test_edit_ethernet_connection(network, ethernet_uuid):
     ethernet_settings2['common']['name'] = 'plinth_test_eth_new'
     ethernet_settings2['common']['interface'] = 'eth1'
     ethernet_settings2['common']['zone'] = 'external'
+    ethernet_settings2['common']['autoconnect'] = False
     ethernet_settings2['ipv4']['method'] = 'auto'
     network.edit_connection(connection, ethernet_settings2)
 
@@ -155,6 +184,7 @@ def test_edit_ethernet_connection(network, ethernet_uuid):
     settings_connection = connection.get_setting_connection()
     assert settings_connection.get_interface_name() == 'eth1'
     assert settings_connection.get_zone() == 'external'
+    assert not settings_connection.get_autoconnect()
 
     settings_ipv4 = connection.get_setting_ip4_config()
     assert settings_ipv4.get_method() == 'auto'
@@ -167,6 +197,7 @@ def test_edit_pppoe_connection(network, pppoe_uuid):
     pppoe_settings2['common']['name'] = 'plinth_test_pppoe_new'
     pppoe_settings2['common']['interface'] = 'eth2'
     pppoe_settings2['common']['zone'] = 'external'
+    pppoe_settings2['common']['autoconnect'] = False
     pppoe_settings2['pppoe']['username'] = 'x-user-new'
     pppoe_settings2['pppoe']['password'] = 'x-password-new'
     network.edit_connection(connection, pppoe_settings2)
@@ -177,6 +208,7 @@ def test_edit_pppoe_connection(network, pppoe_uuid):
     settings_connection = connection.get_setting_connection()
     assert settings_connection.get_interface_name() == 'eth2'
     assert settings_connection.get_zone() == 'external'
+    assert not settings_connection.get_autoconnect()
 
     settings_pppoe = connection.get_setting_pppoe()
     assert settings_pppoe.get_username() == 'x-user-new'
@@ -195,6 +227,7 @@ def test_edit_wifi_connection(network, wifi_uuid):
     wifi_settings2['common']['name'] = 'plinth_test_wifi_new'
     wifi_settings2['common']['interface'] = 'wlan1'
     wifi_settings2['common']['zone'] = 'external'
+    wifi_settings2['common']['autoconnect'] = False
     wifi_settings2['ipv4']['method'] = 'auto'
     wifi_settings2['wireless']['ssid'] = 'plinthtestwifi2'
     wifi_settings2['wireless']['mode'] = 'infrastructure'
@@ -209,6 +242,7 @@ def test_edit_wifi_connection(network, wifi_uuid):
     settings_connection = connection.get_setting_connection()
     assert settings_connection.get_interface_name() == 'wlan1'
     assert settings_connection.get_zone() == 'external'
+    assert not settings_connection.get_autoconnect()
 
     settings_wireless = connection.get_setting_wireless()
     assert settings_wireless.get_ssid().get_data() == b'plinthtestwifi2'
