@@ -22,6 +22,7 @@ import time
 
 from django.contrib import messages
 from django.core.exceptions import ImproperlyConfigured
+from django.http import Http404, HttpResponseRedirect
 from django.template.response import TemplateResponse
 from django.urls import reverse
 from django.utils.http import is_safe_url
@@ -34,7 +35,6 @@ from plinth import package
 from plinth.app import App
 from plinth.daemon import app_is_running
 from plinth.modules.config import get_advanced_mode
-from plinth.modules.storage import views as disk_views
 from plinth.translation import get_language_from_request, set_language
 
 from . import forms, frontpage
@@ -42,6 +42,16 @@ from . import forms, frontpage
 REDIRECT_FIELD_NAME = 'next'
 
 
+def _get_redirect_url_from_param(request):
+    """Return the redirect URL from 'next' GET/POST param."""
+    redirect_to = request.GET.get(REDIRECT_FIELD_NAME, '')
+    redirect_to = request.POST.get(REDIRECT_FIELD_NAME, redirect_to)
+    if is_safe_url(url=redirect_to, allowed_hosts={request.get_host()}):
+        return redirect_to
+
+    return reverse('index')
+
+
 @public
 def index(request):
     """Serve the main index page."""
@@ -54,8 +64,6 @@ def index(request):
     ]
     selected_shortcut = selected_shortcut[0] if selected_shortcut else None
 
-    disk_views.warn_about_low_disk_space(request)
-
     return TemplateResponse(
         request, 'index.html', {
             'title': _('FreedomBox'),
@@ -77,7 +85,6 @@ class AppsIndexView(TemplateView):
 
 def system_index(request):
     """Serve the system index page."""
-    disk_views.warn_about_low_disk_space(request)
     return TemplateResponse(request, 'system.html',
                             {'advanced_mode': get_advanced_mode()})
 
@@ -99,19 +106,12 @@ class LanguageSelectionView(FormView):
 
     def get_success_url(self):
         """Return the URL in the next parameter or home page."""
-        redirect_to = self.request.GET.get(REDIRECT_FIELD_NAME, '')
-        redirect_to = self.request.POST.get(REDIRECT_FIELD_NAME, redirect_to)
-        if is_safe_url(url=redirect_to, host=self.request.get_host()):
-            return redirect_to
-
-        return reverse('index')
+        return _get_redirect_url_from_param(self.request)
 
 
 class AppView(FormView):
     """A generic view for configuring simple apps."""
     clients = []
-    # Set diagnostics_module_name to the module name to show diagnostics button
-    diagnostics_module_name = ""
     name = None
     # List of paragraphs describing the service
     description = ""
@@ -124,6 +124,7 @@ class AppView(FormView):
     template_name = 'app.html'
     manual_page = ''
     port_forwarding_info = None
+    icon_filename = ''
 
     def __init__(self, *args, **kwargs):
         """Initialize the view."""
@@ -187,14 +188,16 @@ class AppView(FormView):
         context = super().get_context_data(*args, **kwargs)
         context.update(self._get_common_status())
         context['app'] = self.app
+        context['app_id'] = self.app.app_id
         context['is_running'] = app_is_running(self.app)
         context['clients'] = self.clients
-        context['diagnostics_module_name'] = self.diagnostics_module_name
         context['name'] = self.name
         context['description'] = self.description
+        context['has_diagnostics'] = self.app.has_diagnostics()
         context['show_status_block'] = self.show_status_block
         context['manual_page'] = self.manual_page
         context['port_forwarding_info'] = self.port_forwarding_info
+        context['icon_filename'] = self.icon_filename
 
         from plinth.modules.firewall.components import Firewall
         context['firewall'] = self.app.get_components_of_type(Firewall)
@@ -205,6 +208,9 @@ class AppView(FormView):
 class SetupView(TemplateView):
     """View to prompt and setup applications."""
     template_name = 'setup.html'
+    name = 'None'
+    # List of paragraphs describing the service
+    description = []
 
     def get_context_data(self, **kwargs):
         """Return the context data rendering the template."""
@@ -221,6 +227,9 @@ class SetupView(TemplateView):
             context[
                 'package_manager_is_busy'] = package.is_package_manager_busy()
 
+        context['name'] = self.name
+        context['description'] = self.description
+
         return context
 
     def dispatch(self, request, *args, **kwargs):
@@ -245,3 +254,15 @@ class SetupView(TemplateView):
                 return self.render_to_response(self.get_context_data())
 
         return super(SetupView, self).dispatch(request, *args, **kwargs)
+
+
+def notification_dismiss(request, id):
+    """Dismiss a notification."""
+    from .notification import Notification
+    notes = Notification.list(key=id, user=request.user)
+    if not notes:
+        raise Http404
+
+    notes[0].dismiss()
+
+    return HttpResponseRedirect(_get_redirect_url_from_param(request))
