@@ -24,8 +24,8 @@ environment.
 import augeas
 
 sudoers_file = '/etc/sudoers.d/plinth'
-aug = augeas.Augeas(
-    flags=augeas.Augeas.NO_LOAD + augeas.Augeas.NO_MODL_AUTOLOAD)
+aug = augeas.Augeas(flags=augeas.Augeas.NO_LOAD +
+                    augeas.Augeas.NO_MODL_AUTOLOAD)
 
 # lens for shell-script config file
 aug.set('/augeas/load/Shellvars/lens', 'Sudoers.lns')
